<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output method="xml"  indent="yes"/>
    
    <xsl:template match="MD_Metadata|Metadata">
        <MDML>
                    <layerInfo>
                        <metadataInfo>
                            <!-- Nivel 0 de la ISO -->
                            <xsl:apply-templates select="./fileIdentifier"/><!--  mdFileID -->
                            <xsl:apply-templates select="./language"/><!-- mdLang -->
                            <xsl:apply-templates select="./characterSet"/><!-- mdChar -->        
                            <xsl:apply-templates select="./parentIdIdentifier"/><!-- mdParentID -->
                            <xsl:if test="./hierarchyLevel">
                                <hierarchyLevels>
                                    <xsl:for-each select="./hierarchyLevel"><!-- mdHrLv -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </hierarchyLevels>
                            </xsl:if>
                            <xsl:if test="./hierarchyLevelName">
                                <hierarchyLevelNames>
                                    <xsl:for-each select="./hierarchyLevelName"><!-- mdHrLvName -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </hierarchyLevelNames>
                            </xsl:if>
                            <xsl:if test="./contact">
                                <contacts>
                                    <xsl:for-each select="./contact">
                                        <xsl:apply-templates select="."/><!-- mdContact --> 
                                    </xsl:for-each>
                                </contacts>    
                            </xsl:if>
                            <xsl:apply-templates select="./dateStamp"/><!-- mdDateSt -->
                            <xsl:apply-templates select="./metadataStandardName"/><!-- mdStanName -->
                            <xsl:apply-templates select="./metadataStandardVersion"/><!-- mdStanVer -->
                            <xsl:apply-templates select="./dataSetURI"/><!-- dataSetURI -->
                            <xsl:if test="./metadataExtensionInfo">
                                <metadataExtensionInfoList>
                                    <xsl:for-each select="./metadataExtensionInfo"><!-- mdExtInfo -->
                                        <xsl:apply-templates select="."/>        
                                    </xsl:for-each>
                                </metadataExtensionInfoList>
                            </xsl:if>
                            <xsl:if test="./identificationInfo">
                                <identificationInfoList>
                                    <xsl:for-each select="./identificationInfo"><!-- dataIdInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </identificationInfoList>
                            </xsl:if>
                            <xsl:if test="contentInfo">
                                <contentInfoList>
                                    <xsl:for-each select="./contentInfo"><!-- contInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </contentInfoList>
                            </xsl:if>
                            <xsl:apply-templates select="./distributionInfo"/><!-- distInfo -->
                            <xsl:if test="./dataQualityInfo">
                                <dataQualityInfoList>
                                    <xsl:for-each select="./dataQualityInfo"><!-- dqInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </dataQualityInfoList>
                            </xsl:if>
                            <xsl:if test="./portrayalCatalogueInfo">
                                <portrayalCatalogueInfoList>
                                    <xsl:for-each select="./portrayalCatalogueInfo"><!-- porCatInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </portrayalCatalogueInfoList>
                            </xsl:if>
                            <xsl:if test="./applicationSchemaInfo">
                                <applicationSchemaInfoList>
                                    <xsl:for-each select="./applicationSchemaInfo"><!-- appSchInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </applicationSchemaInfoList>
                            </xsl:if>
                            <xsl:apply-templates select="./metadataMaintenance"/><!-- mdMaint -->
                        </metadataInfo>                 
                        <sourceInfo>
                            <spatialInfo>
                                <xsl:if test="./spatialRepresentationInfo">
                                    <spatialRepresentationInfoList>
                                        <xsl:for-each select="./spatialRepresentationInfo"><!-- spatRepInfo -->
                                            <xsl:apply-templates select="."/>    
                                        </xsl:for-each>
                                    </spatialRepresentationInfoList>
                                </xsl:if>
                                <SRS>
                                    <xsl:if test="./referenceSystemInfo">
                                        <referenceSystemInfoList>
                                            <xsl:for-each select="./referenceSystemInfo">
                                                <xsl:apply-templates select="."/><!-- refSysInfo -->
                                            </xsl:for-each>
                                        </referenceSystemInfoList>
                                    </xsl:if>
                                </SRS>
                            </spatialInfo>    
                            <descriptiveInfo>
                                <!-- Nivel 1 (hasta 1.1.6) -->
                                <xsl:apply-templates select="MD_Identification"/><!-- ident -->
                            </descriptiveInfo>
                        </sourceInfo>
                        <contacts>
                            
                        </contacts>
                        <rights>
                            <xsl:if test="./metadataConstraints">
                                <metadataConstraintsList>
                                    <xsl:for-each select="./metadataConstraints"><!-- mdConst -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </metadataConstraintsList>
                            </xsl:if>
                        </rights>
                    
    
                    </layerInfo>          
        </MDML>
    </xsl:template>   
    
    <!-- Transformaciones Nivel 0 ISO -->
    <xsl:template match="fileIdentifier">
        <fileIdentifier><xsl:value-of select="."/></fileIdentifier>
    </xsl:template>
    
    <xsl:template match="language">
        <language><xsl:value-of select="."/></language>
    </xsl:template>
    
    <xsl:template match="characterSet">
        <characterSet><xsl:value-of select="."/></characterSet>
    </xsl:template>

    <xsl:template match="parentIdIdentifier">
        <parentIdIdentifier><xsl:value-of select="."/></parentIdIdentifier>
    </xsl:template>
        
    <xsl:template match="hierarchyLevel">
        <hierarchyLevel><xsl:value-of select="."/></hierarchyLevel>
    </xsl:template>
        
    <xsl:template match="hierarchyLevelName">
        <hierarchyLevelName><xsl:value-of select="."/></hierarchyLevelName>
    </xsl:template>
    
    <xsl:template match="contact">
        <contact>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </contact>
    </xsl:template>
    
    
    <!-- ____________________ CI's ____________________________________ -->
    
    
    
    <xsl:template match="CI_ResponsibleParty">
        <xsl:apply-templates select="./individualName"/><!-- rpIndName -->
        <xsl:apply-templates select="./organisationName"/><!-- rpOrgName -->
        <xsl:apply-templates select="./positionName"/><!-- rpPosName -->
        <xsl:apply-templates select="./contactInfo"/><!-- rpCntInfo -->
        <xsl:apply-templates select="./role"/><!-- role -->
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/individualName">
        <individualName><xsl:value-of select="."/></individualName>
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/organisationName">
        <organisationName><xsl:value-of select="."/></organisationName>
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/positionName">
        <positionName><xsl:value-of select="."/></positionName>
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/contactInfo">
        <contactInfo>
            <xsl:apply-templates select="CI_Contact"/>
        </contactInfo>
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/role">
        <role><xsl:value-of select="."/></role>
    </xsl:template>
    
    
    <xsl:template match="CI_Contact">
        <xsl:apply-templates select="./phone"/><!-- cntPhone -->
        <xsl:apply-templates select="./address"/><!-- cntAddress -->
        <xsl:apply-templates select="./onlineResource"/><!-- cntOnlineRes -->
        <xsl:apply-templates select="./hoursOfService"/><!-- cntHours -->
        <xsl:apply-templates select="./contactInstructions"/><!-- cntInstr -->
    </xsl:template>
    
    <xsl:template match="CI_Telephone">
        <xsl:if test="./voice">
            <voices>
                <xsl:for-each select="./voice"><!-- voiceNum -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </voices>
        </xsl:if>
        <xsl:if test="facsimile">
            <facsimiles>
                <xsl:for-each select="./facsimile"><!-- faxNum -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </facsimiles>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="CI_Telephone/voice">
        <voice><xsl:value-of select="."/></voice>
    </xsl:template>
    
    <xsl:template match="CI_Telephone/facsimile">
        <facsimile><xsl:value-of select="."/></facsimile>
    </xsl:template>
    
    <xsl:template match="CI_Address">    
        <xsl:if test="./deliveryPoint">
            <deliveryPoints>
                <xsl:for-each select="./deliveryPoint"><!-- delPoint -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </deliveryPoints>
        </xsl:if>
        <xsl:apply-templates select="./city"/><!-- city -->
        <xsl:apply-templates select="./administrativeArea"/><!-- adminArea -->
        <xsl:apply-templates select="./postalCode"/><!-- postCode -->
        <xsl:apply-templates select="./country"/><!-- country -->
        <xsl:if test="./electronicMailAddress">
            <electronicMailAddresses>
                <xsl:for-each select="./electronicMailAddress"><!-- eMailAdd -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </electronicMailAddresses>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="CI_Address/deliveryPoint">
        <deliveryPoint><xsl:value-of select="."/></deliveryPoint>
    </xsl:template>
    
    <xsl:template match="CI_Address/city">
        <city><xsl:value-of select="."/></city>
    </xsl:template>
    
    <xsl:template match="CI_Address/administrativeArea">
        <administrativeArea><xsl:value-of select="."/></administrativeArea>
    </xsl:template>
    
    <xsl:template match="CI_Address/postalCode">
        <postalCode><xsl:value-of select="."/></postalCode>
    </xsl:template>
    
    <xsl:template match="CI_Address/country">
        <country><xsl:value-of select="."/></country>
    </xsl:template>
    
    <xsl:template match="CI_Address/electronicMailAddress">
        <electronicMailAddress><xsl:value-of select="."/></electronicMailAddress>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource">
        <xsl:apply-templates select="./linkage"/><!-- linkage -->
        <xsl:apply-templates select="./protocol"/><!-- protocol -->
        <xsl:apply-templates select="./applicationProfile"/><!-- appProfile -->
        <xsl:apply-templates select="./name"/><!-- orName -->
        <xsl:apply-templates select="./description"/><!-- orDesc -->
        <xsl:apply-templates select="./function"/><!-- orFunct -->
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/linkage">
        <linkage><xsl:value-of select="."/></linkage>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/protocol">
        <protocol><xsl:value-of select="."/></protocol>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/applicationProfile">
        <applicationProfile><xsl:value-of select="."/></applicationProfile>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/name">
        <name><xsl:value-of select="."/></name>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/description">
        <description><xsl:value-of select="."/></description>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/function">
        <function><xsl:value-of select="."/></function>
    </xsl:template>
    
    <xsl:template match="hoursOfService">
        <hoursOfService><xsl:value-of select="."/></hoursOfService>
    </xsl:template>
    
    <xsl:template match="contactInstructions">
        <contactInstructions><xsl:value-of select="."/></contactInstructions>    
    </xsl:template>
    
    <xsl:template match="CI_Series">
        <xsl:apply-templates select="name"/><!-- seriesName -->
        <xsl:apply-templates select="issueIdentification"/><!-- issId -->
        <xsl:apply-templates select="page"/><!-- artPage -->
    </xsl:template>
    
    <xsl:template match="name">
        <name><xsl:value-of select="."/></name>
    </xsl:template>
    
    <xsl:template match="issueIdentification">
        <issueIdentification><xsl:value-of select="."/></issueIdentification>
    </xsl:template>
    
    <xsl:template match="page">
        <page><xsl:value-of select="."/></page>
    </xsl:template>
    
    <!-- ____________________ CI's ______________________________________________ -->
    
    
    <!-- ____________________ DQ's ____________________________________ -->
    
    <xsl:template match="DQ_DataQuality">
        <xsl:apply-templates select="scope"/><!-- dqScope -->
        <xsl:if test="report">
            <reports>
                <xsl:for-each select="report">
                    <xsl:apply-templates select="."/><!-- dqReport -->
                </xsl:for-each>
            </reports>    
        </xsl:if>
        <xsl:apply-templates select="lineage"/><!-- dataLineage -->
    </xsl:template>
    
    
    <xsl:template match="DQ_Scope">
        <xsl:apply-templates select="level"/><!-- scpLvl -->
        <xsl:apply-templates select="extent"/><!-- scpExt -->
        <xsl:if test="levelDescription"><!-- scpLvlDesc -->
            <levelDescriptionList>
                <xsl:for-each select="levelDescription">
                    <xsl:apply-templates select="."/>    
                </xsl:for-each>
            </levelDescriptionList>    
        </xsl:if>
    </xsl:template>
    
    <!-- ____________________ DQ's ____________________________________ -->
    
    
    
    <!-- ____________________ MD's ____________________________________ -->
    
    <xsl:template match="MD_MetadataExtension">
        <xsl:apply-templates select="./extensionOnlineResource"/><!-- extOnRes -->
        <xsl:if test="./extendedElementInformation"><!-- extEleInfo -->
            <extendedElementInformationList>
                <xsl:for-each select="./extendedElementInformation">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </extendedElementInformationList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="extensionOnlineResource">
        <extensionOnlineResource>
            <xsl:apply-templates select="CI_OnlineResource"></xsl:apply-templates>
        </extensionOnlineResource>
    </xsl:template>
    
    <xsl:template match="extendedElementInformation">
        <extendedElementInformation>
            <xsl:apply-templates select="MD_ExtendedElementInformation"/>
        </extendedElementInformation>
    </xsl:template>
    
    <xsl:template match="MD_ExtendedElementInformation">
        <xsl:apply-templates select="./name"/><!-- extEleName -->
        <xsl:apply-templates select="./shortName"/><!-- extShortName -->
        <xsl:apply-templates select="./domainCode"/><!-- extDomCode -->
        <xsl:apply-templates select="./definition"/><!-- extEleDef -->
        <xsl:apply-templates select="./obligation"/><!-- extEleOb -->
        <xsl:apply-templates select="./condition"/><!-- extEleCond -->
        <xsl:apply-templates select="./dataType"/><!-- eleDataType -->
        <xsl:apply-templates select="./maximumOccurrence"/><!-- extEleMxOc -->
        <xsl:apply-templates select="./domainValue"/><!-- extEleDomVal -->
        <xsl:if test="./parentEntity"><!-- extEleParEnt -->
            <parentEntityList>
                <xsl:for-each select="./parentEntity">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </parentEntityList>
        </xsl:if>
        <xsl:apply-templates select="./rationale"/><!-- extEleRat -->
        <xsl:if test="./rationale">
            <rationaleList>
                <xsl:for-each select="./rationale">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </rationaleList>
        </xsl:if>
        <xsl:if test="./source"><!-- extEleSrc -->
            <sourceList>
                <xsl:for-each select="./source">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </sourceList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="name">
        <name><xsl:value-of select="."/></name>
    </xsl:template>
    
    <xsl:template match="shortName">
        <shortName><xsl:value-of select="."/></shortName>
    </xsl:template>
    
    <xsl:template match="domainCode">
        <domainCode><xsl:value-of select="."/></domainCode>
    </xsl:template>
    
    <xsl:template match="definition">
        <definition><xsl:value-of select="."/></definition>
    </xsl:template>
    
    <xsl:template match="obligation">
        <obligation><xsl:value-of select="."/></obligation>
    </xsl:template>
    
    <xsl:template match="condition">
        <condition><xsl:value-of select="."/></condition>
    </xsl:template>
    
    <xsl:template match="dataType">
        <dataType><xsl:value-of select="."/></dataType>
    </xsl:template>
    
    <xsl:template match="maximumOccurrence">
        <maximumOccurrence><xsl:value-of select="."/></maximumOccurrence>
    </xsl:template>
    
    <xsl:template match="doaminValue">
        <domainValue><xsl:value-of select="."/></domainValue>
    </xsl:template>
    
    <xsl:template match="parentEntity">
        <parentEntity><xsl:value-of select="."/></parentEntity>
    </xsl:template>
    
    <xsl:template match="rule">
        <rule><xsl:value-of select="."/></rule>
    </xsl:template>
    
    <xsl:template match="rationale">
        <rationale><xsl:value-of select="."/></rationale>
    </xsl:template>
    
    <xsl:template match="source">
        <source><xsl:apply-templates select="CI_ResponsibleParty"/></source>
    </xsl:template>
  
  
    <xsl:template match="MD_DataIdentification">
        <xsl:apply-templates select="./citation"/><!-- idCitation -->
        <xsl:apply-templates select="./abstract"/><!-- idAbs -->
        <xsl:apply-templates select="./purpose"/><!-- idPurp -->
        <xsl:if test="./status">
            <statusList>
                <xsl:for-each select="./status"><!-- idStatus -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </statusList>
        </xsl:if>
        <xsl:if test="./pointOfContact">
            <pointsOfContact>
                <xsl:for-each select="./pointOfContact"><!-- idPoC -->
                    <xsl:apply-templates select="."/> 
                </xsl:for-each>
            </pointsOfContact>
        </xsl:if>
        <xsl:if test="./resourceMaintenance">
            <resourceMaintenanceList>
                <xsl:for-each select="./resourceMaintenance"><!-- resMaint -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceMaintenanceList>
        </xsl:if>
        <xsl:if test="./graphicOverview">
            <graphicOverviewList>
                <xsl:for-each select="./graphicOverview"><!-- graphOver -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </graphicOverviewList>
        </xsl:if>
        <xsl:if test="./resourceFormat">
            <resourceFormatList>
                <xsl:for-each select="./resourceFormat"><!-- dsFormat -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceFormatList>
        </xsl:if>
        <xsl:if test="./descriptiveKeywords">
            <descriptiveKeywordsList>
                <xsl:for-each select="./descriptiveKeywords"><!-- descKeys -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </descriptiveKeywordsList>
        </xsl:if>
        <xsl:if test="./resourceSpecificUsage">
            <resourceSpecificUsageList>
                <xsl:for-each select="./resourceSpecificUsage"><!-- idSpecUse -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceSpecificUsageList>
        </xsl:if>
        <xsl:if test="./resourceConstraints">
            <resourceConstraintsList>
                <xsl:for-each select="./resourceConstraints"><!-- resConst -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceConstraintsList>
        </xsl:if>
        <xsl:if test="./aggregationInfo">
            <aggregationInfoList>
                <xsl:for-each select="./aggregationInfo"><!-- aggrInfo -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </aggregationInfoList>
        </xsl:if>
        <xsl:if test="./spatialRepresentationType"><!-- spatRpType -->
            <spatialRepresentationTypeList>
                <xsl:for-each select="./spatialRepresentationType">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </spatialRepresentationTypeList>
        </xsl:if>
        <xsl:if test="./spatialResolution"><!-- dataScale -->
            <spatialResolutionList>
                <xsl:for-each select="./spatialResolution">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </spatialResolutionList>    
        </xsl:if>
        <xsl:if test="./language"><!-- dataLang -->
            <languageList>
                <xsl:for-each select="./language">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </languageList> 
        </xsl:if>    
        <xsl:if test="./characterSet"><!-- dataChar -->
            <characterSetList>
                <xsl:for-each select="./characterSet">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </characterSetList> 
        </xsl:if>    
        <xsl:if test="./topicCategory"><!-- tpCat -->
            <topicCategoryList>
                <xsl:for-each select="./topicCategory">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </topicCategoryList> 
        </xsl:if>    
        <xsl:apply-templates select="./environmentDescription"/><!-- envirDesc -->
        <xsl:if test="./extent"><!-- dataExt -->
            <extentList>
                <xsl:for-each select="./extent">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </extentList> 
        </xsl:if>    
        <xsl:apply-templates select="./supplementalInformation"/><!-- suppInfo -->
        <xsl:apply-templates select="MD_Identification"/>
    </xsl:template>
  
    <xsl:template match="spatialRepresentationType">
        <spatialRepresentationType><xsl:value-of select="."/></spatialRepresentationType>
    </xsl:template>
    
    <xsl:template match="spatialResolution">
        <spatialResolution><xsl:value-of select="."/></spatialResolution>
    </xsl:template>
    
    <xsl:template match="language">
        <language><xsl:value-of select="."/></language>
    </xsl:template>
    
    <xsl:template match="characterSet">
        <characterSet><xsl:value-of select="."/></characterSet>
    </xsl:template>
    
    <xsl:template match="topicCategory">
        <topicCategory><xsl:value-of select="."/></topicCategory>
    </xsl:template>
    
    <xsl:template match="extent">
        <extent><xsl:value-of select="."/></extent>
    </xsl:template>
    
    <xsl:template match="supplementalInformation">
        <supplementalInformation><xsl:value-of select="."/></supplementalInformation>
    </xsl:template>
    
    
  
    <xsl:template match="MD_Identification">
        <xsl:apply-templates select="MD_DataIdentification/citation"/><!-- idCitation -->
        <xsl:apply-templates select="MD_DataIdentification/abstract"/><!-- idAbs -->
        <xsl:apply-templates select="MD_DataIdentification/purpose"/><!-- idPurp -->
        <xsl:if test="MD_DataIdentification/status">
            <statusList>
                <xsl:for-each select="MD_DataIdentification/status"><!-- idStatus -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </statusList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/pointOfContact">
            <pointsOfContact>
                <xsl:for-each select="MD_DataIdentification/pointOfContact"><!-- idPoC -->
                    <xsl:apply-templates select="."/> 
                </xsl:for-each>
            </pointsOfContact>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/resourceMaintenance">
            <resourceMaintenanceList>
                <xsl:for-each select="MD_DataIdentification/resourceMaintenance"><!-- resMaint -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceMaintenanceList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/graphicOverview">
            <graphicOverviewList>
                <xsl:for-each select="MD_DataIdentification/graphicOverview"><!-- graphOver -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </graphicOverviewList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/resourceFormat">
            <resourceFormatList>
                <xsl:for-each select="MD_DataIdentification/resourceFormat"><!-- dsFormat -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceFormatList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/descriptiveKeywords">
            <descriptiveKeywordsList>
                <xsl:for-each select="MD_DataIdentification/descriptiveKeywords"><!-- descKeys -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </descriptiveKeywordsList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/resourceSpecificUsage">
            <resourceSpecificUsageList>
                <xsl:for-each select="MD_DataIdentification/resourceSpecificUsage"><!-- idSpecUse -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceSpecificUsageList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/resourceConstraints">
            <resourceConstraintsList>
                <xsl:for-each select="MD_DataIdentification/resourceConstraints"><!-- resConst -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceConstraintsList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/aggregationInfo">
            <aggregationInfoList>
                <xsl:for-each select="MD_DataIdentification/aggregationInfo"><!-- aggrInfo -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </aggregationInfoList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="citation">
        <citation><xsl:apply-templates select="CI_Citation"/></citation>
    </xsl:template>
    
    <xsl:template match="abstract">
        <abstract><xsl:value-of select="."/></abstract>
    </xsl:template>
    
    <xsl:template match="purpose">
        <purpose><xsl:value-of select="."/></purpose>
    </xsl:template>
    
    <xsl:template match="status">
        <status><xsl:value-of select="."/></status>
    </xsl:template>
    
    <xsl:template match="pointOfContact">
        <pointOfContact><xsl:apply-templates select="CI_ResponsibleParty"/></pointOfContact>
    </xsl:template>
    
    <xsl:template match="resourceMaintenance">
        <resourceMaintenance><xsl:apply-templates select="MD_MaintenanceInformation"/></resourceMaintenance>
    </xsl:template>
    
    <xsl:template match="graphicOverview">
        <graphicOverview><xsl:apply-templates select="MD_BrowseGraphic"/></graphicOverview>
    </xsl:template>
    
    <xsl:template match="resourceFormat">
        <resourceFormat><xsl:apply-templates select="MD_Format"/></resourceFormat>
    </xsl:template>
    
    <xsl:template match="descriptiveKeywords">
        <descriptiveKeywords><xsl:apply-templates select="MD_Keywords"/></descriptiveKeywords>
    </xsl:template>
    
    <xsl:template match="resourceSpecificUsage">
        <resourceSpecificUsage><xsl:apply-templates select="MD_usage"/></resourceSpecificUsage>
    </xsl:template>
    
    <xsl:template match="resourceConstraints">
        <resourceConstraints><xsl:apply-templates select="MD_Constraints"/></resourceConstraints>
    </xsl:template>
    
    <xsl:template match="aggregationInfo">
        <aggregationInfo><xsl:apply-templates select="MD_AggregateInfo"/></aggregationInfo>
    </xsl:template>
    
    
    
    <xsl:template match="MD_MaintenanceInformation">
        <xsl:apply-templates select="./maintenanceAndUpdateFrequency"/><!-- maintFreq -->
        <xsl:apply-templates select="./dateOfNextUpdate"/><!-- dateNext -->
        <xsl:apply-templates select="./userDefinedMaintenanceFrequency"/><!-- usrDefFreq -->
        <xsl:if test="./updateScope"><!-- maintScp -->
            <updateScopeList>
                <xsl:for-each select="./updateScope">
                    <xsl:value-of select="."/>
                </xsl:for-each>
            </updateScopeList>
        </xsl:if>
        <xsl:if test="./updateScopeDescription"><!-- upScpDesc -->
            <updateScopeDescriptionList>
                <xsl:for-each select="./updateScopeDescription">
                    <xsl:value-of select="."/>
                </xsl:for-each>
            </updateScopeDescriptionList>
        </xsl:if>
        <xsl:if test="./maintenanceNote"><!-- maintNote -->
            <maintenanceNoteList>
                <xsl:for-each select="./maintenanceNote">
                    <xsl:value-of select="."/>
                </xsl:for-each>
            </maintenanceNoteList>
        </xsl:if>
        <xsl:if test="./contact"><!-- maintCont -->
            <contactList>
                <xsl:for-each select="./contact">
                    <xsl:value-of select="."/>
                </xsl:for-each>
            </contactList>
        </xsl:if>       
    </xsl:template>
    
    <xsl:template match="maintenanceAndUpdateFrequency">
        <maintenanceAndUpdateFrequency>
            <xsl:value-of select="."/>
        </maintenanceAndUpdateFrequency>
    </xsl:template>
    
    <xsl:template match="dateOfNextUpdate">
        <dateOfNextUpdate>
            <xsl:value-of select="."/>
        </dateOfNextUpdate>
    </xsl:template>
    
    <xsl:template match="userDefinedMaintenanceFrequency">
        <userDefinedMaintenanceFrequency>
            <xsl:value-of select="."/>
        </userDefinedMaintenanceFrequency>
    </xsl:template>
    
    <xsl:template match="updateScope">
        <updateScope>
            <xsl:value-of select="."/>
        </updateScope>
    </xsl:template>
    
    <xsl:template match="updateScopeDescription">
        <updateScopeDescription>
            <xsl:value-of select="MD_ScopeDescription"/>
        </updateScopeDescription>
    </xsl:template>
    
    <xsl:template match="maintenanceNote">
        <maintenanceNote>
            <xsl:value-of select="."/>
        </maintenanceNote>
    </xsl:template>
    
    <xsl:template match="contact">
        <contact>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </contact>
    </xsl:template>
    
    <xsl:template match="MD_ScopeDescription">
       <xsl:apply-templates select="./attributes"/><!-- attribSet -->
        <xsl:apply-templates select="./features"/><!-- featSet -->
        <xsl:apply-templates select="./featureInstances"/><!-- featIntSet -->
        <xsl:apply-templates select="./attributeInstances"/><!-- attribIntSet -->
        <xsl:apply-templates select="./dataSet"/><!-- datasetSet -->
        <xsl:apply-templates select="./other"/><!-- other -->
    </xsl:template>
    
    <xsl:template match="attributes">
        <attributes><xsl:value-of select="."/></attributes>
    </xsl:template>
    
    <xsl:template match="features">
        <features><xsl:value-of select="."/></features>
    </xsl:template>
    
    <xsl:template match="featureInstances">
        <featureInstances><xsl:value-of select="."/></featureInstances>
    </xsl:template>
    
    <xsl:template match="attributteInstances">
        <attributeInstances><xsl:value-of select="."/></attributeInstances>
    </xsl:template>
    
    <xsl:template match="dataSet">
        <dataSet><xsl:value-of select="."/></dataSet>
    </xsl:template>
    
    <xsl:template match="other">
        <other><xsl:value-of select="."/></other>
    </xsl:template>
    
    
    <xsl:template match="MD_BrowseGraphic">
        <xsl:apply-templates select="./fileName"/><!-- bgFileName -->
        <xsl:apply-templates select="./fileDescription"/><!-- bgFileDesc -->
        <xsl:apply-templates select="./fileType"/><!-- bgFileType -->
    </xsl:template>
    
    <xsl:template match="fileName">
        <fileName><xsl:value-of select="."/></fileName>
    </xsl:template>
    
    <xsl:template match="fileDescription">
        <fileDescription><xsl:value-of select="."/></fileDescription>
    </xsl:template>
    
    <xsl:template match="fileType">
        <fileType><xsl:value-of select="."/></fileType>
    </xsl:template>
    
    
    <xsl:template match="MD_Format">
        <xsl:apply-templates select="./name"/><!-- fileName -->
        <xsl:apply-templates select="./version"/><!-- formatVer -->
        <xsl:apply-templates select="./amendmentNumber"/><!-- formatAmdNum -->
        <xsl:apply-templates select="./specification"/><!-- formatSpec -->
        <xsl:apply-templates select="./fileDecompressionTecnique"/><!-- fileDecmTech -->
        <xsl:if test="./formatDistributor">
            <formatDistributorList>
                <xsl:for-each select="./formatDistributor">
                    <xsl:apply-templates select="."/><!-- formatDist -->
                </xsl:for-each>
            </formatDistributorList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="name">
        <name><xsl:value-of select="."/></name>
    </xsl:template>
    
    <xsl:template match="version">
        <version><xsl:value-of select="."/></version>
    </xsl:template>
    
    <xsl:template match="amendmentNumber">
        <amendmentNumber><xsl:value-of select="."/></amendmentNumber>
    </xsl:template>
    
    <xsl:template match="specification">
        <specification><xsl:value-of select="."/></specification>
    </xsl:template>
    
    <xsl:template match="fileDecompressionTechnique">
        <fileDecompressionTechnique><xsl:value-of select="."/></fileDecompressionTechnique>
    </xsl:template>
    
    <xsl:template match="formatDistributor">
        <formatDistributor><xsl:apply-templates select="MD_Distributor"/></formatDistributor>
    </xsl:template>
    
    
    <xsl:template match="MD_Keywords">
        <xsl:if test="./keyword"><!-- keyword -->
            <keywordList>
                <xsl:for-each select="./keyword">
                    <xsl:apply-templates select="."></xsl:apply-templates>
                </xsl:for-each>
            </keywordList>
        </xsl:if>    
        <xsl:apply-templates select="./type"/><!-- keyTyp -->
        <xsl:apply-templates select="./thesaurusName"/><!-- thesaname -->
    </xsl:template>
    
    <xsl:template match="keyword">
        <keyword><xsl:value-of select="."/></keyword>
    </xsl:template>
    
    <xsl:template match="type">
        <type><xsl:value-of select="."/></type>
    </xsl:template>
    
    <xsl:template match="thesaurusName">
        <thesaurusName><xsl:apply-templates select="CI_Citation"/></thesaurusName>
    </xsl:template>
    
  
    <xsl:template match="MD_Distributor">
        <xsl:apply-templates select="./distributorContact"/><!-- distorCont -->
        <xsl:if test="distributionOrderProcess"><!-- distorOrdPrc -->
            <distributionOrderProcessList>
                <xsl:for-each select="./distributionOrderProcess">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </distributionOrderProcessList>
        </xsl:if>
        <xsl:if test="./distributorFormat"><!-- distorFormat -->
            <distributorFormatList>
                <xsl:for-each select="./distributorFormat">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </distributorFormatList>
        </xsl:if>
        <xsl:if test="./distributorTransferOptions"><!-- distorTran -->
            <distributorTransferOptionsList>
                <xsl:for-each select="./distributorTransferOptions">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </distributorTransferOptionsList>
        </xsl:if>
    </xsl:template>
  
    <xsl:template match="distributorContact">
        <distributorContact>
            <xsl:apply-templates select="CI_ResponsibleParty"></xsl:apply-templates>
        </distributorContact>
    </xsl:template> 
    
    <xsl:template match="distributionOrderProcess">
        <distributionOrderProcess>
            <xsl:apply-templates select="MD_StandardOrderProcess"/>
        </distributionOrderProcess>
    </xsl:template> 
    
    <xsl:template match="distributorFormat">
        <distributorFormat>
            <xsl:apply-templates select="MD_Format"/>
        </distributorFormat>
    </xsl:template> 
    
    <xsl:template match="distributorTransferOptions">
        <distributorTransferOptions>
            <xsl:apply-templates select="MD_DigitalTransferOptions"/>
        </distributorTransferOptions>
    </xsl:template> 
  
    <xsl:template match="MD_StandardOrderProcess">
        <xsl:apply-templates select="./fees"/><!-- resFees -->
        <xsl:apply-templates select="./plannedAvailableDateTime"/><!-- planAvDtTm -->
        <xsl:apply-templates select="./orderingInstructions"/><!-- ordInstr -->
        <xsl:apply-templates select="./turnaround"/><!-- ordTurn -->
    </xsl:template>
  
    <xsl:template match="fees">
        <fees><xsl:value-of select="."/></fees>
    </xsl:template>
  
    <xsl:template match="plannedAvailableDateTime">
        <plannedAvailableDateTime><xsl:value-of select="."/></plannedAvailableDateTime>
    </xsl:template>
    
    <xsl:template match="orderingInstructions">
        <orderingInstructions><xsl:value-of select="."/></orderingInstructions>
    </xsl:template>
    
    <xsl:template match="turnaround">
        <turnaround><xsl:value-of select="."/></turnaround>
    </xsl:template>
  
  
    <xsl:template match="MD_DigitalTransferOptions">
        <xsl:apply-templates select="./unitsOfDistribution"/><!-- unitsODist -->
        <xsl:apply-templates select="./transferSize"/><!-- transSize -->
        <xsl:if test="./onLine"><!-- onLineSrc -->
            <onLineList>
                <xsl:for-each select="./onLine">
                    <xsl:apply-templates select="."></xsl:apply-templates>
                </xsl:for-each>
            </onLineList>
        </xsl:if>
        <xsl:apply-templates select="./offLine"/><!-- offLineMed -->
    </xsl:template>
  
    <xsl:template match="unitsOfDistribution">
        <unitsOfDistribution>
            <xsl:value-of select="."/>
        </unitsOfDistribution>
    </xsl:template>
  
    <xsl:template match="transferSize">
        <transferSize>
            <xsl:value-of select="."/>
        </transferSize>
    </xsl:template>
    
    <xsl:template match="onLine">
        <onLine>
            <xsl:apply-templates select="CI_OnlineResource"/>
        </onLine>
    </xsl:template>
    
    <xsl:template match="offLine">
        <offLine>
            <xsl:value-of select="MD_Medium"/>
        </offLine>
    </xsl:template>
  
  
    <xsl:template match="MD_usage">
        <xsl:apply-templates select="./specificUsage"/><!-- specUsage -->
        <xsl:apply-templates select="./usageDateTime"/><!-- usageDate -->
        <xsl:apply-templates select="./userDeterminedLimitations"/><!-- usrDetLim -->
        <xsl:if test="./userContactInfo"><!-- usrCntInfo -->
            <userContactInfoList>
                <xsl:for-each select="./userContactInfo">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </userContactInfoList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="specificUsage">
        <specificUsage>
            <xsl:value-of select="."/>
        </specificUsage>
    </xsl:template>
    
    <xsl:template match="usageDateTime">
        <usageDateTime>
            <xsl:value-of select="."/>
        </usageDateTime>
    </xsl:template>
    
    <xsl:template match="userDeterminedLimitations">
        <userDeterminedLimitations>
            <xsl:value-of select="."/>
        </userDeterminedLimitations>
    </xsl:template>
    
    <xsl:template match="userContactInfo">
        <userContactInfo>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </userContactInfo>
    </xsl:template>
    
    
    <xsl:template match="MD_Constraints">
        <xsl:if test="./useLimitation"><!-- useLimit -->
            <useLimitationList>
                <xsl:for-each select="./useLimitation">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </useLimitationList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="useLimitation">
        <useLimitation>
            <xsl:value-of select="."/>
        </useLimitation>
    </xsl:template>
    
    
    <xsl:template match="MD_Medium">
        <xsl:apply-templates select="./name"/><!-- medName -->
        <xsl:if test="./density"><!-- medDensity -->
            <densityList>
                <xsl:for-each select="./density">
                    <xsl:apply-templates select="."/>            
                </xsl:for-each>
            </densityList>
        </xsl:if>
        <xsl:apply-templates select="./densityUnits"/><!-- medDenUnits -->
        <xsl:apply-templates select="./volumes"/><!-- medVol -->
        <xsl:if test="./mediumFormat"><!-- medFormat -->
            <mediumFormatList>
                <xsl:for-each select="./mediumFormat">
                    <xsl:apply-templates select="."/>            
                </xsl:for-each>
            </mediumFormatList>
        </xsl:if>
        <xsl:apply-templates select="mediumNote"/><!-- medNote -->
    </xsl:template>
    
    <xsl:template match="name">
        <name>
            <xsl:value-of select="."/>
        </name>
    </xsl:template>
    
    <xsl:template match="density">
        <density>
            <xsl:value-of select="."/>
        </density>
    </xsl:template>
    
    <xsl:template match="densityUnits">
        <densityUnits>
            <xsl:value-of select="."/>
        </densityUnits>
    </xsl:template>
    
    <xsl:template match="volumes">
        <volumes>
            <xsl:value-of select="."/>
        </volumes>
    </xsl:template>
    
    <xsl:template match="mediumFormat">
        <mediumFormat>
            <xsl:value-of select="."/>
        </mediumFormat>
    </xsl:template>
    
    <xsl:template match="mediumNote">
        <mediumNote>
            <xsl:value-of select="."/>
        </mediumNote>
    </xsl:template>
    
    
    <xsl:template match="MD_AggregateInformation">
        <xsl:apply-templates select="./aggregateDataSetName"/><!-- aggrDSName -->
        <xsl:apply-templates select="./aggregateDataSetIdentifier"/><!-- aggrDSIdent -->
        <xsl:apply-templates select="./associationType"/><!-- assocType -->
        <xsl:apply-templates select="./initiativeType"/><!-- initType -->
    </xsl:template>
    
    <xsl:template match="aggregateDataSetName">
        <aggregateDataSetName>
            <xsl:apply-templates select="CI_Citation"/>
        </aggregateDataSetName>
    </xsl:template>
    
    <xsl:template match="aggregateDataSetIdentifier">
        <aggregateDataSetIdentifier>
            <xsl:apply-templates select="MD_identifier"/>
        </aggregateDataSetIdentifier>
    </xsl:template>
    
    <xsl:template match="associationType">
        <associationType>
            <xsl:value-of select="."/>
        </associationType>
    </xsl:template>
    
    <xsl:template match="initiativeType">
        <initiativeType>
            <xsl:value-of select="."/>
        </initiativeType>
    </xsl:template>
    
    
    <xsl:template match="MD_Identifier">
        <xsl:apply-templates select="./authority"/><!-- identAuth -->
        <xsl:apply-templates select="./code"/><!-- identCode -->
    </xsl:template>
    
    <xsl:template match="authority">
        <authority><xsl:apply-templates select="CI_Citation"/></authority>
    </xsl:template>
    
    <xsl:template match="code">
        <code><xsl:value-of select="."/></code>
    </xsl:template>
    
      
    <xsl:template match="MD_FeatureCatalogueDescription">
        <xsl:apply-templates select="./complianceCode"/><!-- compCode -->
        <xsl:if test="./language"><!-- catLang -->
            <languageList>
                <xsl:for-each select="./language">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </languageList>
        </xsl:if>
        <xsl:apply-templates select="./includedWithDataset"/><!-- incWithDS -->
        <xsl:if test="./featureTypes"><!-- catFetTyps -->
            <featureTypesList>
                <xsl:for-each select="./featureTypes">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </featureTypesList>
        </xsl:if>
        <xsl:if test="./featureCatalogueCitation"><!-- catCitation -->
            <featureCatalogueCitationList>
                <xsl:for-each select="./featureCatalogueCitation">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </featureCatalogueCitationList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="complianceCode">
        <complianceCode><xsl:value-of select="."/></complianceCode>
    </xsl:template>
    
    <xsl:template match="language">
        <language><xsl:value-of select="."/></language>
    </xsl:template>
    
    <xsl:template match="includedWithDataset">
        <includedWithDataset><xsl:value-of select="."/></includedWithDataset>
    </xsl:template>
    
    <xsl:template match="featureTypes">
        <featureTypes><xsl:value-of select="."/></featureTypes>
    </xsl:template>
    
    <xsl:template match="featureCatalogueCitation">
        <featureCatalogueCitation><xsl:value-of select="."/></featureCatalogueCitation>
    </xsl:template>
    
    
    <xsl:template match="MD_Distribution">
        <xsl:if test="distributionFormat"><!-- distFormat -->
            <distributionFormatList>
                <xsl:for-each select="distributionFormat">
                    <xsl:apply-templates select="."/>    
                </xsl:for-each>
            </distributionFormatList>    
        </xsl:if>
        <xsl:if test="distributor"><!-- distributor -->
            <distributorList>
                <xsl:for-each select="distributor">
                    <xsl:apply-templates select="."/>    
                </xsl:for-each>
            </distributorList>    
        </xsl:if>
        <xsl:if test="transferOptions"><!-- distTranOps -->
            <transferOptionsList>
                <xsl:for-each select="transferOptions">
                    <xsl:apply-templates select="."/>    
                </xsl:for-each>
            </transferOptionsList>    
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="distributionFormat">
        <distributionFormat>
            <xsl:apply-templates select="MD_Format"/>
        </distributionFormat>
    </xsl:template>
    
    <xsl:template match="distributor">
        <distributor>
            <xsl:apply-templates select="MD_Distributor"/>
        </distributor>
    </xsl:template>
    
    <xsl:template match="transferOptions">
        <transferOptions>
            <xsl:apply-templates select="MD_DigitalTransferOptions"/>
        </transferOptions>
    </xsl:template>
    
    <xsl:template match="MD_ContentInformation">
        <xsl:if test="MD_FeatureCatalogueDescription">
            <xsl:apply-templates select="MD_FeatureCatalogueDescription"/>
        </xsl:if>
        <xsl:if test="MD_CoverageDescription">
            <xsl:apply-templates select="MD_CoverageDescription"/>
        </xsl:if>
        <xsl:if test="MD_ImageDescription">
            <xsl:apply-templates select="MD_ImageDescription"/>
        </xsl:if>
    </xsl:template>
    
    
    <xsl:template match="MD_CoverageDescription">
        <xsl:apply-templates select="./attributeDescription"/><!-- attDesc -->
        <xsl:apply-templates select="contentType"/><!-- contentTyp -->
        <xsl:if test="./dimension"><!-- covDim -->
            <dimensionList>
                <xsl:for-each select="./dimension">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </dimensionList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="attributeDescription">
        <attributeDescription><xsl:value-of select="."/></attributeDescription>
    </xsl:template>
    
    <xsl:template match="contentType">
        <contentType><xsl:value-of select="."/></contentType>
    </xsl:template>
    
    <xsl:template match="dimension">
        <dimension><xsl:apply-templates select="MD_RangeDimension"/></dimension>
    </xsl:template>
    
    
    <xsl:template match="MD_RangeDimension">
        <xsl:apply-templates select="./sequenceIdentifier"/><!-- seqID -->
        <xsl:apply-templates select="./descriptor"/><!-- dimDescrp -->
    </xsl:template>
    
    
    <xsl:template match="sequenceIdentifier">
        <sequenceIdentifier><xsl:value-of select="."/></sequenceIdentifier>
    </xsl:template>
    
    <xsl:template match="descriptor">
        <descriptor><xsl:value-of select="."/></descriptor>
    </xsl:template>
    
    
    <xsl:template match="MD_ImageDescription">
        <xsl:apply-templates select="MD_CoverageDescription"/>
        <xsl:apply-templates select="./illuminationElevationAngle"/><!-- illElevAng -->
        <xsl:apply-templates select="./illuminationAzimuthAngle"/><!-- illAziAng -->
        <xsl:apply-templates select="./imagingCondition"/><!-- imagCond -->
        <xsl:apply-templates select="./imageQualityCode"/><!-- imagQuCode -->
        <xsl:apply-templates select="./cloudCoverPercentage"/><!-- cloudCovPer -->
        <xsl:apply-templates select="./processingLevelCode"/><!-- prcTypCde -->
        <xsl:apply-templates select="./compressionGenerationQuantity"/><!-- cmpGenQuan -->
        <xsl:apply-templates select="./triangulationIndicator"/><!-- trianInd -->
        <xsl:apply-templates select="./radiometricCalibrationDataAvailability"/><!-- radCalDatAv -->
        <xsl:apply-templates select="./cameraCalibrationInformationAvailability"/><!-- camCalInAv -->
        <xsl:apply-templates select="./filmDistortionInformationAvailability"/><!-- filmDistInAv -->
        <xsl:apply-templates select="./lensDistortionInformationAvailability"/><!-- lensDistInAv -->
    </xsl:template>
    
    <xsl:template match="illuminationElevationAngle">
        <illuminationElevationAngle>
            <xsl:value-of select="."/>
        </illuminationElevationAngle>
    </xsl:template>
    
    <xsl:template match="illuminationAzimuthAngle">
        <illuminationAzimuthAngle>
            <xsl:value-of select="."/>
        </illuminationAzimuthAngle>
    </xsl:template>
    
    <xsl:template match="imagingCondition">
        <imagingCondition>
            <xsl:value-of select="."/>
        </imagingCondition>
    </xsl:template>
    
    <xsl:template match="imagingQualityCode">
        <imagingQualityCode>
            <xsl:apply-templates select="MD_Identifier"/>
        </imagingQualityCode>
    </xsl:template>
    
    <xsl:template match="cloudCoverPercentage">
        <cloudCoverPercentage>
            <xsl:value-of select="."/>
        </cloudCoverPercentage>
    </xsl:template>
    
    <xsl:template match="processingLevelCode">
        <processingLevelCode>
            <xsl:apply-templates select="MD_Identifier"/>
        </processingLevelCode>
    </xsl:template>
    
    <xsl:template match="compressionGenerationQuantity">
        <compressionGenerationQuantity>
            <xsl:value-of select="."/>
        </compressionGenerationQuantity>
    </xsl:template>
    
    <xsl:template match="triangulationIndicator">
        <triangulationIndicator>
            <xsl:value-of select="."/>
        </triangulationIndicator>
    </xsl:template>
    
    <xsl:template match="radiometricCalibrationDataAvailability">
        <radiometricCalibrationDataAvailability>
            <xsl:value-of select="."/>
        </radiometricCalibrationDataAvailability>
    </xsl:template>
    
    <xsl:template match="cameraCalibrationInformationAvailability">
        <cameraCalibrationInformationAvailability>
            <xsl:value-of select="."/>
        </cameraCalibrationInformationAvailability>
    </xsl:template>
    
    
    <xsl:template match="filmDistortionInformationAvailability">
        <filmDistortionInformationAvailability>
            <xsl:value-of select="."/>
        </filmDistortionInformationAvailability>
    </xsl:template>
    
    <xsl:template match="lensDistortionInformationAvailability">
        <lensDistortionInformationAvailability>
            <xsl:value-of select="."/>
        </lensDistortionInformationAvailability>
    </xsl:template>
    
    
    <xsl:template match="EX_Extent">
        <xsl:apply-templates select="./description"/><!-- exDesc -->
        <xsl:if test="./geographicElement"><!-- geoEle -->
            <geographicElementList>
                <xsl:for-each select="./geographicElement">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </geographicElementList>
        </xsl:if>
        <xsl:if test="./temporalElement"><!-- tempEle -->
            <temporalElementList>
                <xsl:for-each select="./temporalElement">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </temporalElementList>
        </xsl:if>
        <xsl:if test="./verticalElement"><!-- vertEle -->
            <verticalElementList>
                <xsl:for-each select="./verticalElement">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </verticalElementList>
        </xsl:if>       
    </xsl:template>
    
    <xsl:template match="description">
        <description><xsl:value-of select="."/></description>
    </xsl:template>
    
    <xsl:template match="geographicElement">
        <geographicElement>
            <xsl:apply-templates select="EX_GeographicExtent | EX_GeographicBoundingBox | EX_BoundingPolygon | EX_GeographicDescription"/>
        </geographicElement>
    </xsl:template>
    
    <xsl:template match="temporalElement">
        <temporalElement>
            <xsl:apply-templates select="EX_TemporalExtent"/>
        </temporalElement>
    </xsl:template>
    
    <xsl:template match="verticalElement">
        <verticalElement>
            <xsl:apply-templates select="EX_VerticalExtent"/>
        </verticalElement>
    </xsl:template>
    
    <xsl:template match="MD_RepresentativeFraction">
        <xsl:apply-templates select="./denominator"/><!-- rfDenom -->
    </xsl:template>
    
    <xsl:template match="denominator">
        <denominator>
            <xsl:value-of select="."/>
        </denominator>
    </xsl:template>
    
    
    <xsl:template match="MD_ReferenceSystem">
        <xsl:apply-templates select="./referenceSystemIdentifier"/><!-- refSysId -->
    </xsl:template>
    
    <xsl:template match="referenceSystemIdentifier">
        <referenceSystemIdentifier>
            <xsl:apply-templates select="RS_Identifier"/>
        </referenceSystemIdentifier>
    </xsl:template>
    
    
    <xsl:template match="MD_ApplicationSchemaInformation">
        <xsl:apply-templates select="./name"/><!-- asName -->
        <xsl:apply-templates select="./schemaLanguage"/><!-- asSchLang -->
        <xsl:apply-templates select="./constraintLanguage"/><!-- asCstLang -->
        <xsl:apply-templates select="./schemaAscii"/><!-- asAscii -->
        <xsl:apply-templates select="./graphicsFile"/><!-- asGraFile -->
        <xsl:apply-templates select="./softwareDevelopmentFile"/><!-- asSwDevFile -->
        <xsl:apply-templates select="./softwareDevelopmentFileFormat"/><!-- asSwDevFiFt -->
    </xsl:template>
    
    <xsl:template match="name">
        <name>
            <xsl:apply-templates select="CI_Citation"/>
        </name>
    </xsl:template>
    
    <xsl:template match="schemaLanguage">
        <schemaLanguage>
            <xsl:value-of select="."/>
        </schemaLanguage>
    </xsl:template>
    
    <xsl:template match="constraintLanguage">
        <constraintLanguage>
            <xsl:value-of select="."/>
        </constraintLanguage>
    </xsl:template>
    
    <xsl:template match="schemaAscii">
        <schemaAscii>
            <xsl:value-of select="."/>
        </schemaAscii>
    </xsl:template>
    
    <xsl:template match="graphicsFile">
        <graphicsFile>
            <xsl:value-of select="."/>
        </graphicsFile>
    </xsl:template>
    
    <xsl:template match="softwareDevelopmentFile">
        <softwareDevelopmentFile>
            <xsl:value-of select="."/>
        </softwareDevelopmentFile>
    </xsl:template>
    
    <xsl:template match="softwareDevelopmentFileFormat">
        <softwareDevelopmentFileFormat>
            <xsl:value-of select="."/>
        </softwareDevelopmentFileFormat>
    </xsl:template>
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    <!-- ____________________ MD's ____________________________________ -->
    

    <!-- ____________________ RS's ____________________________________ -->
    
    <xsl:template match="RS_Identifier">
        <xsl:apply-templates select="./codeSpace"/><!-- identCodeSpace -->
        <xsl:apply-templates select="./version"/><!-- identVrsn -->
    </xsl:template>
    
    <xsl:template match="codeSpace">
        <codeSpace>
            <xsl:value-of select="."/>
        </codeSpace>
    </xsl:template>
    
    <xsl:template match="version">
        <version>
            <xsl:value-of select="."/>
        </version>
    </xsl:template>
    
    
    <!-- ____________________ RS's ____________________________________ -->
    
    
    
    
    
    <!-- ____________________ EX 's ____________________________________ -->

    <xsl:template match="EX_GeographicExtent">
        <xsl:apply-templates select="./extentTypeCode"/><!-- exTypCode -->
        <xsl:if test="EX_BoundingPolygon">
            <xsl:apply-templates select="."></xsl:apply-templates>
        </xsl:if>
        <xsl:if test="EX_GeographicBoundingBox">
            <xsl:apply-templates select="."></xsl:apply-templates>
        </xsl:if>
        <xsl:if test="EX_GeographicDescription">
            <xsl:apply-templates select="."></xsl:apply-templates>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="extentTypeCode">
        <extentTypeCode>
            <xsl:value-of select="."/>
        </extentTypeCode>
    </xsl:template>
    
    
    <xsl:template match="EX_BoundingPolygon">
        <xsl:if test="./polygon"><!-- polygon -->
            <polygonList>
                <xsl:for-each select="./polygon">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </polygonList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="polygon">
        <polygon>
            <xsl:value-of select="."/>
        </polygon>
    </xsl:template>
    
    
    <xsl:template match="EX_GeographicBoundingBox">
        <xsl:apply-templates select="./westBoundLongitude"/><!-- westBL -->
        <xsl:apply-templates select="./eastBoundLongitude"/><!-- eastBL -->
        <xsl:apply-templates select="./southBoundLatitude"/><!-- southBL -->
        <xsl:apply-templates select="./northBoundLatitude"/><!-- northBL -->
    </xsl:template>
    
    <xsl:template match="westBoundLongitude">
        <westBoundLongitude>
            <xsl:value-of select="."/>
        </westBoundLongitude>
    </xsl:template>
    
    <xsl:template match="eastBoundLongitude">
        <eastBoundLongitude>
            <xsl:value-of select="."/>
        </eastBoundLongitude>
    </xsl:template>
    
    <xsl:template match="southBoundLatitude">
        <southBoundLatitude>
            <xsl:value-of select="."/>
        </southBoundLatitude>
    </xsl:template>
    
    <xsl:template match="northBoundLatitude">
        <northBoundLatitude>
            <xsl:value-of select="."/>
        </northBoundLatitude>
    </xsl:template>
    
    
    <xsl:template match="EX_GeographicDescription">
        <xsl:apply-templates select="./geographicIdentifier"/><!-- geoId -->
    </xsl:template>
    
    <xsl:template match="geographicIdentifier">
        <geographicIdentifier>
            <xsl:value-of select="."/>
        </geographicIdentifier>
    </xsl:template>
    
    
    <xsl:template match="EX_TemporalExtent">
        <xsl:apply-templates select="./extent"/><!--exTemp -->
        <xsl:if test="EX_SpatialTemporalExtent">
            <xsl:apply-templates select="."/>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="extent">
        <extent>
            <xsl:value-of select="."/>
        </extent>
    </xsl:template>
    
    
    <xsl:template match="EX_SpatialTemporalExtent">
        <xsl:if test="./spatialExtent">
            <spatialExtentList>
                <xsl:for-each select="./spatialExtent">
                    <xsl:apply-templates select="."/><!-- exSpat -->
                </xsl:for-each>
            </spatialExtentList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="spatialExtent">
        <spatialExtent>
            <xsl:value-of select="."/>
        </spatialExtent>
    </xsl:template>
    
    
    <xsl:template match="EX_VerticalExtent">
        <xsl:apply-templates select="./minimumValue"/><!-- vertMinVal -->
        <xsl:apply-templates select="./maximumValue"/><!-- vertMaxVal -->
        <xsl:apply-templates select="./unitOfMeasure"/><!-- vertUoM -->
        <xsl:apply-templates select="./verticalDatum"/><!-- vertDatum -->
    </xsl:template>
    
    <xsl:template match="minimumValue">
        <minimumValue>
            <xsl:value-of select="."/>
        </minimumValue>
    </xsl:template>
    
    <xsl:template match="maximumValue">
        <maximumValue>
            <xsl:value-of select="."/>
        </maximumValue>
    </xsl:template>
    
    <xsl:template match="unitOfMeasure">
        <unitOfMeasure>
            <xsl:value-of select="."/>
        </unitOfMeasure>
    </xsl:template>
    
    <xsl:template match="verticalDatum">
        <verticalDatum>
            <xsl:value-of select="."/>
        </verticalDatum>
    </xsl:template>
    

    <!-- Falta implementar TM_Primitive (ISO 19108) y SC_VerticalDatum (ISO 19111) -->

    <!-- ____________________ EX 's ____________________________________ -->
    


    <!-- ____________________ LI 's ____________________________________ -->
    
    <xsl:template match="LI_Lineage">
        <xsl:apply-templates select="./statement"/><!-- statement -->
        <xsl:if test="./processStep"><!-- prcStep -->
            <processStepList>
                <xsl:for-each select="./processStep">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </processStepList>
        </xsl:if>
        <xsl:if test="./source"><!-- dataSource -->
            <sourceList>
                <xsl:for-each select="./source">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </sourceList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="statement">
        <statement>
            <xsl:value-of select="."/>
        </statement>
    </xsl:template>
    
    <xsl:template match="processStep">
        <processStep>
            <xsl:apply-templates select="LI_ProcessStep"/>
        </processStep>
    </xsl:template>
    
    <xsl:template match="source">
        <source>
            <xsl:apply-templates select="LI_Source"/>
        </source>
    </xsl:template>
    
    
    <xsl:template match="LI_ProcessStep">
        <xsl:apply-templates select="./description"/><!-- stepDesc -->
        <xsl:apply-templates select="./rationale"/><!-- stepRat -->
        <xsl:apply-templates select="./dateTime"/><!-- stepDateTm -->
        <xsl:if test="./processor"><!-- stepProc -->
            <processorList>
                <xsl:for-each select="./processor">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </processorList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="description">
        <description>
            <xsl:value-of select="."/>
        </description>
    </xsl:template>
    
    <xsl:template match="rationale">
        <rationale>
            <xsl:value-of select="."/>
        </rationale>
    </xsl:template>
    
    <xsl:template match="dateTime">
        <dateTime>
            <xsl:value-of select="."/>
        </dateTime>
    </xsl:template>
    
    <xsl:template match="processor">
        <processor>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </processor>
    </xsl:template>
    
    
    <xsl:template match="LI_Source">
        <xsl:apply-templates select="./description"/><!-- srcDesc -->
        <xsl:apply-templates select="./scaleDenominator"/><!-- srcScale -->
        <xsl:apply-templates select="./sourceReferenceSystem"/><!-- srcRefSys -->
        <xsl:apply-templates select="./sourceCitation"/><!-- srcCitatn -->
        <xsl:if test="./sourceExtent"><!-- srcExt -->
            <sourceExtentList>
                <xsl:for-each select="./sourceExtent">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </sourceExtentList>
        </xsl:if>
        <xsl:if test="./sourceStep"><!-- srcStep -->
            <sourceStepList>
                <xsl:for-each select="./sourceStep">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </sourceStepList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="description">
        <description>
            <xsl:value-of select="."/>
        </description>
    </xsl:template>
    
    <xsl:template match="scaleDenominator">
        <denominator>
            <xsl:apply-templates select="MD_RepresentativeFraction"/>
        </denominator>
    </xsl:template>
    
    <xsl:template match="sourceReferenceSystem">
        <sourceReferenceSystem>
            <xsl:apply-templates select="MD_ReferenceSystem"/>
        </sourceReferenceSystem>
    </xsl:template>
    
    <xsl:template match="sourceCitation">
        <sourceCitation>
            <xsl:apply-templates select="CI_Citation"/>
        </sourceCitation>
    </xsl:template>
    
    <xsl:template match="sourceExtent">
        <sourceExtent>
            <xsl:apply-templates select="EX_Extent"/>
        </sourceExtent>
    </xsl:template>
    
    <xsl:template match="sourceStep">
        <sourceStep>
            <xsl:apply-templates select="LI_ProcessStep"></xsl:apply-templates>
        </sourceStep>
    </xsl:template>
    
    <!-- ____________________ LI 's ____________________________________ -->
    

    <xsl:template match="phone">
        <phone>
            <xsl:apply-templates select="CI_Telephone"/>
        </phone>
    </xsl:template>
    
    <xsl:template match="address">
        <xsl:apply-templates select="CI_Address"/>
    </xsl:template>
    
    
    <xsl:template match="onlineResource">
        <onlineResource>
            <xsl:apply-templates select="CI_OnlineResource"/>
        </onlineResource>
    </xsl:template>
    
    
    
    <xsl:template match="dateStamp">
        <dateStamp><xsl:value-of select="."/></dateStamp>
    </xsl:template>
    
    <xsl:template match="metadataStandardName">
        <metadataStandardName><xsl:value-of select="."/></metadataStandardName>
    </xsl:template>
    
    <xsl:template match="metadataStandardVersion">
        <metadataStandardVersion><xsl:value-of select="."/></metadataStandardVersion>
    </xsl:template>
    
    <xsl:template match="dataSetURI">
        <dataSetURI><xsl:value-of select="."/></dataSetURI>
    </xsl:template>
    
    <xsl:template match="metadataExtensionInfo">
        <metadataExtensionInfo><xsl:value-of select="."/></metadataExtensionInfo>
    </xsl:template>
    
    <xsl:template match="identificationInfo">
        <identificationInfo>
            <xsl:apply-templates select="MD_DataIdentification"/>
        </identificationInfo>
    </xsl:template>
    
    <xsl:template match="contentInfo">
        <contentInfo><xsl:apply-templates select="MD_FeatureCatalogueDescription | MD_ImageDescription | MD_CoverageDescription"/></contentInfo>
    </xsl:template>
    
    
    <xsl:template match="distributionInfo">
        <distributionInfo><xsl:apply-templates select="MD_Distribution"/></distributionInfo>
    </xsl:template>
    
    
    <xsl:template match="dataQualityInfo">
        <dataQualityInfo>
            <xsl:apply-templates select="DQ_DataQuality"/>
        </dataQualityInfo>
    </xsl:template>
        
    <xsl:template match="portrayalCatalogueInfo">
        <portrayalCatalogueInfo>
            <xsl:apply-templates select="MD_PortrayalCatalogueReference"/>
        </portrayalCatalogueInfo>
    </xsl:template>
    
    <xsl:template match="metadataConstraints">
        <metadataConstraints>
            <xsl:apply-templates select="MD_Constraints"/>
        </metadataConstraints>
    </xsl:template>
        
    <xsl:template match="applicationSchemaInfo">
        <applicationSchemaInfo>
            <xsl:apply-templates select="MD_ApplicationSchemaInformation"></xsl:apply-templates>
        </applicationSchemaInfo>
    </xsl:template>
        
    <xsl:template match="metadataMaintenance">
        <metadataMaintenance>
            <xsl:apply-templates select="MD_MaintenanceInformation"/>
        </metadataMaintenance>
    </xsl:template>
        
    <xsl:template match="spatialRepresentationInfo">
        <spatialRepresentationInfo>
            <xsl:apply-templates select="MD_SpatialRepresentation"/>
        </spatialRepresentationInfo>
    </xsl:template>    
    
    <xsl:template match="referenceSystemInfo">
        <referenceSystemInfo>
            <xsl:apply-templates select="MD_ReferenceSystem"/>
        </referenceSystemInfo>
    </xsl:template>
    
    
    
    
    <!-- MD_ApplicationSchemaInformation, MD_SpatialRepresentation, MD_MetadataExtensionInformation... -->
    
    
    
    
    
    
    
    
    
    
    
    
    
        
    
    <xsl:template match="scope">
        <scope>
            <xsl:apply-templates select="DQ_Scope"/>
        </scope>
    </xsl:template>
    
    <xsl:template match="extent">
        <extent><xsl:apply-templates select="EX_Extent"/></extent>
    </xsl:template>

    <xsl:template match="levelDescription">
        <levelDescription><xsl:value-of select="."/></levelDescription>    
    </xsl:template>
    
    <xsl:template match="report">
        <report>
            <xsl:if test="nameOfMeasure"><!-- measName -->
                <namesOfMeasure>
                    <xsl:for-each select="nameOfMeasure">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                </namesOfMeasure>
            </xsl:if>
            <xsl:apply-templates select="measureIdentification"/><!-- measId -->
            <xsl:apply-templates select="measureDescription"/><!-- measDesc -->
            <xsl:apply-templates select="evaluationMethodType"/><!-- evalMethType -->
            <xsl:apply-templates select="evaluationProcedure"/><!-- evalProc -->
            <xsl:if test="dateTime"><!-- measDateTm -->
                <dateTimes>
                    <xsl:for-each select="dateTime">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                </dateTimes>
            </xsl:if>
            <xsl:apply-templates select="result"/><!-- measResult -->
            <xsl:apply-templates select="result"/><!-- 2 ocurrencias -->
        </report>
    </xsl:template>
    
    <xsl:template match="nameOfMeasure">
        <nameOfMeasure><xsl:value-of select="."/></nameOfMeasure>
    </xsl:template>
    
    <xsl:template match="measureIdentification">
        <measureIdentification><xsl:value-of select="."/></measureIdentification>
    </xsl:template>
    
    <xsl:template match="measureDescription">
       <measureDescription><xsl:value-of select="."/></measureDescription>
    </xsl:template>
    
    <xsl:template match="evaluationMethodType">
        <evaluationMethodType><xsl:value-of select="."/></evaluationMethodType>
    </xsl:template>
    
    <xsl:template match="evaluationProcedure">
        <evaluationProcedure>
            <xsl:apply-templates select="CI_Citation/title"/><!-- resTitle -->
            <xsl:if test="CI_Citation/alternateTitle"><!-- resAltTitle -->
                <alternateTitles>
                    <xsl:for-each select="./alternateTitle">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </alternateTitles>
            </xsl:if>
            <xsl:if test="CI_Citation/date"><!-- resRefDate -->
                <dates>
                    <xsl:for-each select="./date">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </dates>
            </xsl:if>
            <xsl:if test="CI_Citation/edition"/><!-- resEd -->
            <xsl:if test="CI_Citation/editionDate"/><!-- resEdDate -->
            <xsl:if test="CI_Citation/identifier"><!-- citId -->
                <identifiers>
                    <xsl:for-each select="./identifier">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </identifiers>
            </xsl:if>
            <xsl:if test="CI_Citation/citedResponsibleParty"><!-- citRespParty -->
                <citedResponsiblePartyList>
                    <xsl:for-each select="citedResponsibleParty">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </citedResponsiblePartyList>
            </xsl:if>
            <xsl:if test="CI_Citation/presentationForm"><!-- presForm -->
                <presentationForms>
                    <xsl:for-each select="presentationForm">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </presentationForms>
            </xsl:if>
            <xsl:apply-templates select="CI_Citation/series"/><!-- datasetSeries -->            
            <xsl:apply-templates select="CI_Citation/otherCitationDetails"/><!-- otherCitDet --> 
            <xsl:apply-templates select="CI_Citation/collectiveTitle"/><!-- collTitle -->            
            <xsl:apply-templates select="CI_Citation/ISBN"/><!-- isbn -->   
            <xsl:apply-templates select="CI_Citation/ISSN"/><!-- issn -->            
        </evaluationProcedure>
    </xsl:template>
        
    <xsl:template match="CI_Citation/title">
        <title><xsl:value-of select="."/></title>
    </xsl:template>
    
    <xsl:template match="CI_Citation/alternateTitle">
        <alternateTitle><xsl:value-of select="."/></alternateTitle>
    </xsl:template>
    
    <xsl:template match="CI_Citation/date">
        <date>
            <xsl:apply-templates select="CI_Date/date"/><!-- refDate -->
            <xsl:apply-templates select="CI_Date/dateType"/><!-- refDateType -->
        </date>
    </xsl:template>
    
    <xsl:template match="CI_Date/date">
        <date><xsl:value-of select="."/></date>
    </xsl:template>
    
    <xsl:template match="CI_Date/dateType">
        <dateType><xsl:value-of select="."/></dateType>
    </xsl:template>
    
    <xsl:template match="CI_Citation/edition">
        <edition><xsl:value-of select="."/></edition>
    </xsl:template>
    
    <xsl:template match="CI_Citation/editionDate">
        <editionDate><xsl:value-of select="."/></editionDate>
    </xsl:template>
    
    <xsl:template match="CI_Citation/identifier">
        <identifier><xsl:apply-templates select="MD_Identifier"/>></identifier>
    </xsl:template>
    
    <xsl:template match="CI_Citation/citedResponsibleParty">
        <citedResponsibleParty>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </citedResponsibleParty>
    </xsl:template>
    
    <xsl:template match="CI_Citation/presentationForm">
        <presentationForm><xsl:value-of select="."/></presentationForm>
    </xsl:template>
    
    <xsl:template match="CI_Citation/series">
        <series><xsl:apply-templates select="CI_Series"/>></series>
    </xsl:template>
    
    <xsl:template match="CI_Citation/otherCitationDetails">
        <otherCitationDetails><xsl:apply-templates select="."/>></otherCitationDetails>
    </xsl:template>
    
    <xsl:template match="CI_Citation/collectiveTitle">
        <collectiveTitle><xsl:apply-templates select="."/>></collectiveTitle>
    </xsl:template>
    
    <xsl:template match="CI_Citation/ISBN">
        <ISBN><xsl:apply-templates select="."/>></ISBN>
    </xsl:template>
    
    <xsl:template match="CI_Citation/ISSN">
        <ISSN><xsl:apply-templates select="."/>></ISSN>
    </xsl:template>
    
    <xsl:template match="dateTime">
        <dateTime><xsl:value-of select="."/></dateTime>
    </xsl:template>
    
    <xsl:template match="result">
        <result><xsl:value-of select="."/></result>
    </xsl:template>
        
        
        
        
        
        
        
        
        
        
        
        
 </xsl:stylesheet>   
