<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output method="xml"  indent="yes"/>
    
    <xsl:template match="MD_Metadata|Metadata">
        <mdml_metadata>
                    <layerInfo>
                        <metadataInfo>
                            <!-- Nivel 0 de la ISO -->
                            <xsl:apply-templates select="./mdFileID"/><!--  mdFileID -->
                            <xsl:apply-templates select="./mdLang"/><!-- mdLang -->
                            <xsl:apply-templates select="./mdchar"/><!-- mdChar -->        
                            <xsl:apply-templates select="./mdParentID"/><!-- mdParentID -->
                            <xsl:if test="./hierarchyLevel">
                                <hierarchyLevels>
                                    <xsl:for-each select="./hierarchyLevel"><!-- mdHrLv -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </hierarchyLevels>
                            </xsl:if>
                            <xsl:if test="./hierarchyLevelName">
                                <hierarchyLevelNames>
                                    <xsl:for-each select="./hierarchyLevelName"><!-- mdHrLvName -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </hierarchyLevelNames>
                            </xsl:if>
                            <xsl:if test="./contact">
                                <contacts>
                                    <xsl:for-each select="./contact">
                                        <xsl:apply-templates select="."/><!-- mdContact --> 
                                    </xsl:for-each>
                                </contacts>    
                            </xsl:if>
                            <xsl:apply-templates select="./dateStamp"/><!-- mdDateSt -->
                            <xsl:apply-templates select="./metadataStandardName"/><!-- mdStanName -->
                            <xsl:apply-templates select="./metadataStandardVersion"/><!-- mdStanVer -->
                            <xsl:apply-templates select="./dataSetURI"/><!-- dataSetURI -->
                            <xsl:if test="./metadataExtensionInfo">
                                <metadataExtensionInfoList>
                                    <xsl:for-each select="./metadataExtensionInfo"><!-- mdExtInfo -->
                                        <xsl:apply-templates select="."/>        
                                    </xsl:for-each>
                                </metadataExtensionInfoList>
                            </xsl:if>
                            <xsl:if test="./identificationInfo">
                                <identificationInfoList>
                                    <xsl:for-each select="./identificationInfo"><!-- dataIdInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </identificationInfoList>
                            </xsl:if>
                            <xsl:if test="contentInfo">
                                <contentInfoList>
                                    <xsl:for-each select="./contentInfo"><!-- contInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </contentInfoList>
                            </xsl:if>
                            <xsl:apply-templates select="./distributionInfo"/><!-- distInfo -->
                            <xsl:if test="./dataQualityInfo">
                                <dataQualityInfoList>
                                    <xsl:for-each select="./dataQualityInfo"><!-- dqInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </dataQualityInfoList>
                            </xsl:if>
                            <xsl:if test="./portrayalCatalogueInfo">
                                <portrayalCatalogueInfoList>
                                    <xsl:for-each select="./portrayalCatalogueInfo"><!-- porCatInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </portrayalCatalogueInfoList>
                            </xsl:if>
                            <xsl:if test="./applicationSchemaInfo">
                                <applicationSchemaInfoList>
                                    <xsl:for-each select="./applicationSchemaInfo"><!-- appSchInfo -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </applicationSchemaInfoList>
                            </xsl:if>
                            <xsl:apply-templates select="./metadataMaintenance"/><!-- mdMaint -->
                        </metadataInfo>    
                        <contacts>
                            
                        </contacts>
                        <rights>
                            <xsl:if test="./metadataConstraints">
                                <metadataConstraintsList>
                                    <xsl:for-each select="./metadataConstraints"><!-- mdConst -->
                                        <xsl:apply-templates select="."/>
                                    </xsl:for-each>
                                </metadataConstraintsList>
                            </xsl:if>
                        </rights>
             
                        <sourceInfo>
                            <spatialInfo>
                                <xsl:if test="./spatialRepresentationInfo">
                                    <spatialRepresentationInfoList>
                                        <xsl:for-each select="./spatialRepresentationInfo"><!-- spatRepInfo -->
                                            <xsl:apply-templates select="."/>    
                                        </xsl:for-each>
                                    </spatialRepresentationInfoList>
                                </xsl:if>
                                <SRS>
                                    <xsl:if test="./referenceSystemInfo">
                                        <referenceSystemInfoList>
                                            <xsl:for-each select="./referenceSystemInfo">
                                                <xsl:apply-templates select="."/><!-- refSysInfo -->
                                            </xsl:for-each>
                                        </referenceSystemInfoList>
                                    </xsl:if>
                                </SRS>
                            </spatialInfo>    
                            <descriptiveInfo>
                                <!-- Nivel 1 (hasta 1.1.6) -->
                                <xsl:apply-templates select="MD_Identification"/><!-- ident -->
                            </descriptiveInfo>
                        </sourceInfo>

                    </layerInfo>          
        </mdml_metadata>
    </xsl:template>   
    
    <!-- Transformaciones Nivel 0 ISO -->
    <xsl:template match="mdFileID">
        <mdml_mdFileID><xsl:value-of select="."/></mdml_mdFileID>
    </xsl:template>
    
    <xsl:template match="mdLang">
        <mdml_mdLang><xsl:value-of select="."/></mdml_mdLang>
    </xsl:template>
    
    <xsl:template match="mdChar">
        <mdml_mdChar><xsl:value-of select="."/></mdml_mdChar>
    </xsl:template>

    <xsl:template match="parentIdIdentifier">
        <mdml_mdParentID><xsl:value-of select="."/></mdml_mdParentID>
    </xsl:template>
        
    <xsl:template match="hierarchyLevel">
        <mdml_mdHrLv><xsl:value-of select="."/></mdml_mdHrLv>
    </xsl:template>
        
    <xsl:template match="hierarchyLevelName">
        <mdml_mdHrLvName><xsl:value-of select="."/></mdml_mdHrLvName>
    </xsl:template>
    
    <xsl:template match="contact">
        <mdml_mdContact>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </mdml_mdContact>
    </xsl:template>
    
    
    <!-- ____________________ CI's ____________________________________ -->
    
    
    
    <xsl:template match="CI_ResponsibleParty">
        <xsl:apply-templates select="./individualName"/><!-- rpIndName -->
        <xsl:apply-templates select="./organisationName"/><!-- rpOrgName -->
        <xsl:apply-templates select="./positionName"/><!-- rpPosName -->
        <xsl:apply-templates select="./contactInfo"/><!-- rpCntInfo -->
        <xsl:apply-templates select="./role"/><!-- role -->
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/individualName">
        <mdml_rpIndName><xsl:value-of select="."/></mdml_rpIndName>
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/organisationName">
        <mdml_rpOrgName><xsl:value-of select="."/></mdml_rpOrgName>
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/positionName">
        <mdml_rpPosName><xsl:value-of select="."/></mdml_rpPosName>
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/contactInfo">
        <mdml_rpCntInfo>
            <xsl:apply-templates select="CI_Contact"/>
        </mdml_rpCntInfo>
    </xsl:template>
    
    <xsl:template match="CI_ResponsibleParty/role">
        <mdml_role><xsl:value-of select="."/></mdml_role>
    </xsl:template>
    
    
    <xsl:template match="CI_Contact">
        <xsl:apply-templates select="./phone"/><!-- cntPhone -->
        <xsl:apply-templates select="./address"/><!-- cntAddress -->
        <xsl:apply-templates select="./onlineResource"/><!-- cntOnlineRes -->
        <xsl:apply-templates select="./hoursOfService"/><!-- cntHours -->
        <xsl:apply-templates select="./contactInstructions"/><!-- cntInstr -->
    </xsl:template>
    
    <xsl:template match="CI_Telephone">
        <xsl:if test="./voice">
            <voices>
                <xsl:for-each select="./voice"><!-- voiceNum -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </voices>
        </xsl:if>
        <xsl:if test="facsimile">
            <facsimiles>
                <xsl:for-each select="./facsimile"><!-- faxNum -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </facsimiles>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="CI_Telephone/voice">
        <mdml_voiceNum><xsl:value-of select="."/></mdml_voiceNum>
    </xsl:template>
    
    <xsl:template match="CI_Telephone/facsimile">
        <mdml_faxNum><xsl:value-of select="."/></mdml_faxNum>
    </xsl:template>
    
    <xsl:template match="CI_Address">    
        <xsl:if test="./deliveryPoint">
            <deliveryPoints>
                <xsl:for-each select="./deliveryPoint"><!-- delPoint -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </deliveryPoints>
        </xsl:if>
        <xsl:apply-templates select="./city"/><!-- city -->
        <xsl:apply-templates select="./administrativeArea"/><!-- adminArea -->
        <xsl:apply-templates select="./postalCode"/><!-- postCode -->
        <xsl:apply-templates select="./country"/><!-- country -->
        <xsl:if test="./electronicMailAddress">
            <electronicMailAddresses>
                <xsl:for-each select="./electronicMailAddress"><!-- eMailAdd -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </electronicMailAddresses>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="CI_Address/deliveryPoint">
        <deliveryPoint><xsl:value-of select="."/></deliveryPoint>
    </xsl:template>
    
    <xsl:template match="CI_Address/city">
        <mdml_city><xsl:value-of select="."/></mdml_city>
    </xsl:template>
    
    <xsl:template match="CI_Address/administrativeArea">
        <mdml_adminArea><xsl:value-of select="."/></mdml_adminArea>
    </xsl:template>
    
    <xsl:template match="CI_Address/postalCode">
        <mdml_postCode><xsl:value-of select="."/></mdml_postCode>
    </xsl:template>
    
    <xsl:template match="CI_Address/country">
        <mdml_country><xsl:value-of select="."/></mdml_country>
    </xsl:template>
    
    <xsl:template match="CI_Address/electronicMailAddress">
        <mdml_eMailAdd><xsl:value-of select="."/></mdml_eMailAdd>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource">
        <xsl:apply-templates select="./linkage"/><!-- linkage -->
        <xsl:apply-templates select="./protocol"/><!-- protocol -->
        <xsl:apply-templates select="./applicationProfile"/><!-- appProfile -->
        <xsl:apply-templates select="./name"/><!-- orName -->
        <xsl:apply-templates select="./description"/><!-- orDesc -->
        <xsl:apply-templates select="./function"/><!-- orFunct -->
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/linkage">
        <mdml_linkage><xsl:value-of select="."/></mdml_linkage>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/protocol">
        <mdml_protocol><xsl:value-of select="."/></mdml_protocol>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/applicationProfile">
        <mdml_appProfile><xsl:value-of select="."/></mdml_appProfile>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/name">
        <mdml_orName><xsl:value-of select="."/></mdml_orName>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/description">
        <mdml_orDesc><xsl:value-of select="."/></mdml_orDesc>
    </xsl:template>
    
    <xsl:template match="CI_OnlineResource/function">
        <mdml_orFunct><xsl:value-of select="."/></mdml_orFunct>
    </xsl:template>
    
    <xsl:template match="hoursOfService">
        <mdml_cntHours><xsl:value-of select="."/></mdml_cntHours>
    </xsl:template>
    
    <xsl:template match="contactInstructions">
        <mdml_cntInstr><xsl:value-of select="."/></mdml_cntInstr>    
    </xsl:template>
    
    <xsl:template match="CI_Series">
        <xsl:apply-templates select="name"/><!-- seriesName -->
        <xsl:apply-templates select="issueIdentification"/><!-- issId -->
        <xsl:apply-templates select="page"/><!-- artPage -->
    </xsl:template>
    
    <xsl:template match="name">
        <mdml_seriesName><xsl:value-of select="."/></mdml_seriesName>
    </xsl:template>
    
    <xsl:template match="issueIdentification">
        <mdml_issId><xsl:value-of select="."/></mdml_issId>
    </xsl:template>
    
    <xsl:template match="page">
        <mdml_artPage><xsl:value-of select="."/></mdml_artPage>
    </xsl:template>
    
    <xsl:template match="CI_Citation">
            <xsl:apply-templates select="CI_Citation/title"/><!-- resTitle -->
            <xsl:if test="CI_Citation/alternateTitle"><!-- resAltTitle -->
                <alternateTitles>
                    <xsl:for-each select="./alternateTitle">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </alternateTitles>
            </xsl:if>
            <xsl:if test="CI_Citation/date"><!-- resRefDate -->
                <dates>
                    <xsl:for-each select="./date">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </dates>
            </xsl:if>
            <xsl:if test="CI_Citation/edition"/><!-- resEd -->
            <xsl:if test="CI_Citation/editionDate"/><!-- resEdDate -->
            <xsl:if test="CI_Citation/identifier"><!-- citId -->
                <identifiers>
                    <xsl:for-each select="./identifier">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </identifiers>
            </xsl:if>
            <xsl:if test="CI_Citation/citedResponsibleParty"><!-- citRespParty -->
                <citedResponsiblePartyList>
                    <xsl:for-each select="citedResponsibleParty">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </citedResponsiblePartyList>
            </xsl:if>
            <xsl:if test="CI_Citation/presentationForm"><!-- presForm -->
                <presentationForms>
                    <xsl:for-each select="presentationForm">
                        <xsl:apply-templates select="."/>            
                    </xsl:for-each>
                </presentationForms>
            </xsl:if>
            <xsl:apply-templates select="CI_Citation/series"/><!-- datasetSeries -->            
            <xsl:apply-templates select="CI_Citation/otherCitationDetails"/><!-- otherCitDet --> 
            <xsl:apply-templates select="CI_Citation/collectiveTitle"/><!-- collTitle -->            
            <xsl:apply-templates select="CI_Citation/ISBN"/><!-- isbn -->   
            <xsl:apply-templates select="CI_Citation/ISSN"/><!-- issn -->           
    </xsl:template>
    
      
    <xsl:template match="CI_Citation/title">
        <mdml_resTitle><xsl:value-of select="."/></mdml_resTitle>
    </xsl:template>
    
    <xsl:template match="CI_Citation/alternateTitle">
        <mdml_resAltTitle><xsl:value-of select="."/></mdml_resAltTitle>
    </xsl:template>
    
    <xsl:template match="CI_Citation/date">
        <mdml_resRefDate>
            <xsl:apply-templates select="CI_Date/date"/><!-- refDate -->
            <xsl:apply-templates select="CI_Date/dateType"/><!-- refDateType -->
        </mdml_resRefDate>
    </xsl:template>
    
    <xsl:template match="CI_Date/date">
        <mdml_refDate><xsl:value-of select="."/></mdml_refDate>
    </xsl:template>
    
    <xsl:template match="CI_Date/dateType">
        <mdml_refDateType><xsl:value-of select="."/></mdml_refDateType>
    </xsl:template>
    
    <xsl:template match="CI_Citation/edition">
        <mdml_resEd><xsl:value-of select="."/></mdml_resEd>
    </xsl:template>
    
    <xsl:template match="CI_Citation/editionDate">
        <mdml_resEdDate><xsl:value-of select="."/></mdml_resEdDate>
    </xsl:template>
    
    <xsl:template match="CI_Citation/identifier">
        <mdml_citId><xsl:apply-templates select="MD_Identifier"/>></mdml_citId>
    </xsl:template>
    
    <xsl:template match="CI_Citation/citedResponsibleParty">
        <mdml_citRespParty>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </mdml_citRespParty>
    </xsl:template>
    
    <xsl:template match="CI_Citation/presentationForm">
        <mdml_presForm><xsl:value-of select="."/></mdml_presForm>
    </xsl:template>
    
    <xsl:template match="CI_Citation/series">
        <mdml_datasetSeries><xsl:apply-templates select="CI_Series"/></mdml_datasetSeries>
    </xsl:template>
    
    <xsl:template match="CI_Citation/otherCitationDetails">
        <mdml_otherCitDet><xsl:apply-templates select="."/>></mdml_otherCitDet>
    </xsl:template>
    
    <xsl:template match="CI_Citation/collectiveTitle">
        <mdml_collTitle><xsl:apply-templates select="."/>></mdml_collTitle>
    </xsl:template>
    
    <xsl:template match="CI_Citation/ISBN">
        <mdml_isbn><xsl:apply-templates select="."/>></mdml_isbn>
    </xsl:template>
    
    <xsl:template match="CI_Citation/ISSN">
        <mdml_issn><xsl:apply-templates select="."/>></mdml_issn>
    </xsl:template>
    

    
    <!-- ____________________ CI's ______________________________________________ -->
    
    
    <!-- ____________________ DQ's ____________________________________ -->
    
    <xsl:template match="DQ_DataQuality">
        <xsl:apply-templates select="scope"/><!-- dqScope -->
        <xsl:if test="report">
            <reports>
                <xsl:for-each select="report">
                    <xsl:apply-templates select="."/><!-- dqReport -->
                </xsl:for-each>
            </reports>    
        </xsl:if>
        <xsl:apply-templates select="lineage"/><!-- dataLineage -->
    </xsl:template>
    
    
    <xsl:template match="DQ_Scope">
        <xsl:apply-templates select="level"/><!-- scpLvl -->
        <xsl:apply-templates select="extent"/><!-- scpExt -->
        <xsl:if test="levelDescription"><!-- scpLvlDesc -->
            <levelDescriptionList>
                <xsl:for-each select="levelDescription">
                    <xsl:apply-templates select="."/>    
                </xsl:for-each>
            </levelDescriptionList>    
        </xsl:if>
    </xsl:template>
    
    
<xsl:template match="DQ_Element">
            <xsl:if test="nameOfMeasure"><!-- measName -->
                <namesOfMeasure>
                    <xsl:for-each select="nameOfMeasure">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                </namesOfMeasure>
            </xsl:if>
            <xsl:apply-templates select="measureIdentification"/><!-- measId -->
            <xsl:apply-templates select="measureDescription"/><!-- measDesc -->
            <xsl:apply-templates select="evaluationMethodType"/><!-- evalMethType -->
            <xsl:apply-templates select="evaluationProcedure"/><!-- evalProc -->
            <xsl:if test="dateTime"><!-- measDateTm -->
                <dateTimes>
                    <xsl:for-each select="dateTime">
                        <xsl:apply-templates select="."/>
                    </xsl:for-each>
                </dateTimes>
            </xsl:if>
            <xsl:apply-templates select="result"/><!-- measResult -->
            <xsl:apply-templates select="result"/><!-- 2 ocurrencias -->
    
</xsl:template>
    
    <!-- ____________________ DQ's ____________________________________ -->
    
    
    
    <!-- ____________________ MD's ____________________________________ -->
    
    <xsl:template match="MD_MetadataExtension">
        <xsl:apply-templates select="./extensionOnlineResource"/><!-- extOnRes -->
        <xsl:if test="./extendedElementInformation"><!-- extEleInfo -->
            <extendedElementInformationList>
                <xsl:for-each select="./extendedElementInformation">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </extendedElementInformationList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="extensionOnlineResource">
        <mdml_extOnRes>
            <xsl:apply-templates select="CI_OnlineResource"/>
        </mdml_extOnRes>
    </xsl:template>
    
    <xsl:template match="extendedElementInformation">
        <mdml_extEleInfo>
            <xsl:apply-templates select="MD_ExtendedElementInformation"/>
        </mdml_extEleInfo>
    </xsl:template>
    
    <xsl:template match="MD_ExtendedElementInformation">
        <xsl:apply-templates select="./name"/><!-- extEleName -->
        <xsl:apply-templates select="./shortName"/><!-- extShortName -->
        <xsl:apply-templates select="./domainCode"/><!-- extDomCode -->
        <xsl:apply-templates select="./definition"/><!-- extEleDef -->
        <xsl:apply-templates select="./obligation"/><!-- extEleOb -->
        <xsl:apply-templates select="./condition"/><!-- extEleCond -->
        <xsl:apply-templates select="./dataType"/><!-- eleDataType -->
        <xsl:apply-templates select="./maximumOccurrence"/><!-- extEleMxOc -->
        <xsl:apply-templates select="./domainValue"/><!-- extEleDomVal -->
        <xsl:if test="./parentEntity"><!-- extEleParEnt -->
            <parentEntityList>
                <xsl:for-each select="./parentEntity">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </parentEntityList>
        </xsl:if>
        <xsl:apply-templates select="./rule"/><!-- extEleRule -->
        <xsl:apply-templates select="./rationale"/><!-- extEleRat -->
        <xsl:if test="./rationale">
            <rationaleList>
                <xsl:for-each select="./rationale">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </rationaleList>
        </xsl:if>
        <xsl:if test="./source"><!-- extEleSrc -->
            <sourceList>
                <xsl:for-each select="./source">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </sourceList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="name">
        <mdml_extEleName><xsl:value-of select="."/></mdml_extEleName>
    </xsl:template>
    
    <xsl:template match="shortName">
        <mdml_extShortName><xsl:value-of select="."/></mdml_extShortName>
    </xsl:template>
    
    <xsl:template match="domainCode">
        <mdml_extDomCode><xsl:value-of select="."/></mdml_extDomCode>
    </xsl:template>
    
    <xsl:template match="definition">
        <mdml_extEleDef><xsl:value-of select="."/></mdml_extEleDef>
    </xsl:template>
    
    <xsl:template match="obligation">
        <mdml_extEleOb><xsl:value-of select="."/></mdml_extEleOb>
    </xsl:template>
    
    <xsl:template match="condition">
        <mdml_extEleCond><xsl:value-of select="."/></mdml_extEleCond>
    </xsl:template>
    
    <xsl:template match="dataType">
        <mdml_extDataType><xsl:value-of select="."/></mdml_extDataType>
    </xsl:template>
    
    <xsl:template match="maximumOccurrence">
        <mdml_extMxOc><xsl:value-of select="."/></mdml_extMxOc>
    </xsl:template>
    
    <xsl:template match="domainValue">
        <mdml_extEleDomVal><xsl:value-of select="."/></mdml_extEleDomVal>
    </xsl:template>
    
    <xsl:template match="parentEntity">
        <mdml_extEleParEnt><xsl:value-of select="."/></mdml_extEleParEnt>
    </xsl:template>
    
    <xsl:template match="rule">
        <mdml_extEleRule><xsl:value-of select="."/></mdml_extEleRule>
    </xsl:template>
    
    <xsl:template match="rationale">
        <mdml_extEleRat><xsl:value-of select="."/></mdml_extEleRat>
    </xsl:template>
    
    <xsl:template match="source">
        <mdml_extEleSrc><xsl:apply-templates select="CI_ResponsibleParty"/></mdml_extEleSrc>
    </xsl:template>
  
  
    <xsl:template match="MD_DataIdentification">
        <xsl:apply-templates select="./citation"/><!-- idCitation -->
        <xsl:apply-templates select="./abstract"/><!-- idAbs -->
        <xsl:apply-templates select="./purpose"/><!-- idPurp -->
        <xsl:if test="./status">
            <statusList>
                <xsl:for-each select="./status"><!-- idStatus -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </statusList>
        </xsl:if>
        <xsl:if test="./pointOfContact">
            <pointsOfContact>
                <xsl:for-each select="./pointOfContact"><!-- idPoC -->
                    <xsl:apply-templates select="."/> 
                </xsl:for-each>
            </pointsOfContact>
        </xsl:if>
        <xsl:if test="./resourceMaintenance">
            <resourceMaintenanceList>
                <xsl:for-each select="./resourceMaintenance"><!-- resMaint -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceMaintenanceList>
        </xsl:if>
        <xsl:if test="./graphicOverview">
            <graphicOverviewList>
                <xsl:for-each select="./graphicOverview"><!-- graphOver -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </graphicOverviewList>
        </xsl:if>
        <xsl:if test="./resourceFormat">
            <resourceFormatList>
                <xsl:for-each select="./resourceFormat"><!-- dsFormat -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceFormatList>
        </xsl:if>
        <xsl:if test="./descriptiveKeywords">
            <descriptiveKeywordsList>
                <xsl:for-each select="./descriptiveKeywords"><!-- descKeys -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </descriptiveKeywordsList>
        </xsl:if>
        <xsl:if test="./resourceSpecificUsage">
            <resourceSpecificUsageList>
                <xsl:for-each select="./resourceSpecificUsage"><!-- idSpecUse -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceSpecificUsageList>
        </xsl:if>
        <xsl:if test="./resourceConstraints">
            <resourceConstraintsList>
                <xsl:for-each select="./resourceConstraints"><!-- resConst -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceConstraintsList>
        </xsl:if>
        <xsl:if test="./aggregationInfo">
            <aggregationInfoList>
                <xsl:for-each select="./aggregationInfo"><!-- aggrInfo -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </aggregationInfoList>
        </xsl:if>
        <xsl:if test="./spatialRepresentationType"><!-- spatRpType -->
            <spatialRepresentationTypeList>
                <xsl:for-each select="./spatialRepresentationType">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </spatialRepresentationTypeList>
        </xsl:if>
        <xsl:if test="./spatialResolution"><!-- dataScale -->
            <spatialResolutionList>
                <xsl:for-each select="./spatialResolution">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </spatialResolutionList>    
        </xsl:if>
        <xsl:if test="./language"><!-- dataLang -->
            <languageList>
                <xsl:for-each select="./language">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </languageList> 
        </xsl:if>    
        <xsl:if test="./characterSet"><!-- dataChar -->
            <characterSetList>
                <xsl:for-each select="./characterSet">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </characterSetList> 
        </xsl:if>    
        <xsl:if test="./topicCategory"><!-- tpCat -->
            <topicCategoryList>
                <xsl:for-each select="./topicCategory">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </topicCategoryList> 
        </xsl:if>    
        <xsl:apply-templates select="./environmentDescription"/><!-- envirDesc -->
        <xsl:if test="./extent"><!-- dataExt -->
            <extentList>
                <xsl:for-each select="./extent">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </extentList> 
        </xsl:if>    
        <xsl:apply-templates select="./supplementalInformation"/><!-- suppInfo -->
        <xsl:apply-templates select="MD_Identification"/>
    </xsl:template>
  
    <xsl:template match="spatialRepresentationType">
        <mdml_spatRpType><xsl:value-of select="."/></mdml_spatRpType>
    </xsl:template>
    
    <xsl:template match="spatialResolution">
        <mdml_dataScale><xsl:value-of select="."/></mdml_dataScale>
    </xsl:template>
    
    <xsl:template match="language">
        <mdml_dataLang><xsl:value-of select="."/></mdml_dataLang>
    </xsl:template>
    
    <xsl:template match="characterSet">
        <mdml_dataChar><xsl:value-of select="."/></mdml_dataChar>
    </xsl:template>
    
    <xsl:template match="topicCategory">
        <mdml_tpCat><xsl:value-of select="."/></mdml_tpCat>
    </xsl:template>
    
    
<xsl:template match="environmentDescription">
        <mdml_envirDesc><xsl:value-of select="."/></mdml_envirDesc>
    </xsl:template>
    
    <xsl:template match="extent">
        <mdml_dataExt><xsl:value-of select="."/></mdml_dataExt>
    </xsl:template>
    
    <xsl:template match="supplementalInformation">
        <mdml_suppInfo><xsl:value-of select="."/></mdml_suppInfo>
    </xsl:template>
    
    
  
    <xsl:template match="MD_Identification">
        <xsl:apply-templates select="MD_DataIdentification/citation"/><!-- idCitation -->
        <xsl:apply-templates select="MD_DataIdentification/abstract"/><!-- idAbs -->
        <xsl:apply-templates select="MD_DataIdentification/purpose"/><!-- idPurp -->
        <xsl:if test="MD_DataIdentification/status">
            <statusList>
                <xsl:for-each select="MD_DataIdentification/status"><!-- idStatus -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </statusList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/pointOfContact">
            <pointsOfContact>
                <xsl:for-each select="MD_DataIdentification/pointOfContact"><!-- idPoC -->
                    <xsl:apply-templates select="."/> 
                </xsl:for-each>
            </pointsOfContact>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/resourceMaintenance">
            <resourceMaintenanceList>
                <xsl:for-each select="MD_DataIdentification/resourceMaintenance"><!-- resMaint -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceMaintenanceList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/graphicOverview">
            <graphicOverviewList>
                <xsl:for-each select="MD_DataIdentification/graphicOverview"><!-- graphOver -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </graphicOverviewList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/resourceFormat">
            <resourceFormatList>
                <xsl:for-each select="MD_DataIdentification/resourceFormat"><!-- dsFormat -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceFormatList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/descriptiveKeywords">
            <descriptiveKeywordsList>
                <xsl:for-each select="MD_DataIdentification/descriptiveKeywords"><!-- descKeys -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </descriptiveKeywordsList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/resourceSpecificUsage">
            <resourceSpecificUsageList>
                <xsl:for-each select="MD_DataIdentification/resourceSpecificUsage"><!-- idSpecUse -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceSpecificUsageList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/resourceConstraints">
            <resourceConstraintsList>
                <xsl:for-each select="MD_DataIdentification/resourceConstraints"><!-- resConst -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </resourceConstraintsList>
        </xsl:if>
        <xsl:if test="MD_DataIdentification/aggregationInfo">
            <aggregationInfoList>
                <xsl:for-each select="MD_DataIdentification/aggregationInfo"><!-- aggrInfo -->
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </aggregationInfoList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="citation">
        <mdml_idCitation><xsl:apply-templates select="CI_Citation"/></mdml_idCitation>
    </xsl:template>
    
    <xsl:template match="abstract">
        <mdml_idAbs><xsl:value-of select="."/></mdml_idAbs>
    </xsl:template>
    
    <xsl:template match="purpose">
        <mdml_idPurp><xsl:value-of select="."/></mdml_idPurp>
    </xsl:template>
    
    <xsl:template match="status">
        <mdml_idStatus><xsl:value-of select="."/></mdml_idStatus>
    </xsl:template>
    
    <xsl:template match="pointOfContact">
        <mdml_idPoC><xsl:apply-templates select="CI_ResponsibleParty"/></mdml_idPoC>
    </xsl:template>
    
    <xsl:template match="resourceMaintenance">
        <mdml_resMaint><xsl:apply-templates select="MD_MaintenanceInformation"/></mdml_resMaint>
    </xsl:template>
    
    <xsl:template match="graphicOverview">
        <mdml_graphOver><xsl:apply-templates select="MD_BrowseGraphic"/></mdml_graphOver>
    </xsl:template>
    
    <xsl:template match="resourceFormat">
        <mdml_dsFormat><xsl:apply-templates select="MD_Format"/></mdml_dsFormat>
    </xsl:template>
    
    <xsl:template match="descriptiveKeywords">
        <mdml_descKeys><xsl:apply-templates select="MD_Keywords"/></mdml_descKeys>
    </xsl:template>
    
    <xsl:template match="resourceSpecificUsage">
        <mdml_idSpecUse><xsl:apply-templates select="MD_usage"/></mdml_idSpecUse>
    </xsl:template>
    
    <xsl:template match="resourceConstraints">
        <mdml_resConst><xsl:apply-templates select="MD_Constraints"/></mdml_resConst>
    </xsl:template>
    
    <xsl:template match="aggregationInfo">
        <mdml_aggrInfo><xsl:apply-templates select="MD_AggregateInfo"/></mdml_aggrInfo>
    </xsl:template>
    
    
    
    <xsl:template match="MD_MaintenanceInformation">
        <xsl:apply-templates select="./maintenanceAndUpdateFrequency"/><!-- maintFreq -->
        <xsl:apply-templates select="./dateOfNextUpdate"/><!-- dateNext -->
        <xsl:apply-templates select="./userDefinedMaintenanceFrequency"/><!-- usrDefFreq -->
        <xsl:if test="./updateScope"><!-- maintScp -->
            <updateScopeList>
                <xsl:for-each select="./updateScope">
                    <xsl:value-of select="."/>
                </xsl:for-each>
            </updateScopeList>
        </xsl:if>
        <xsl:if test="./updateScopeDescription"><!-- upScpDesc -->
            <updateScopeDescriptionList>
                <xsl:for-each select="./updateScopeDescription">
                    <xsl:value-of select="."/>
                </xsl:for-each>
            </updateScopeDescriptionList>
        </xsl:if>
        <xsl:if test="./maintenanceNote"><!-- maintNote -->
            <maintenanceNoteList>
                <xsl:for-each select="./maintenanceNote">
                    <xsl:value-of select="."/>
                </xsl:for-each>
            </maintenanceNoteList>
        </xsl:if>
        <xsl:if test="./contact"><!-- maintCont -->
            <contactList>
                <xsl:for-each select="./contact">
                    <xsl:value-of select="."/>
                </xsl:for-each>
            </contactList>
        </xsl:if>       
    </xsl:template>
    
    <xsl:template match="maintenanceAndUpdateFrequency">
        <mdml_maintFreq>
            <xsl:value-of select="."/>
        </mdml_maintFreq>
    </xsl:template>
    
    <xsl:template match="dateOfNextUpdate">
        <mdml_dateNext>
            <xsl:value-of select="."/>
        </mdml_dateNext>
    </xsl:template>
    
    <xsl:template match="userDefinedMaintenanceFrequency">
        <mdml_usrDefFreq>
            <xsl:value-of select="."/>
        </mdml_usrDefFreq>
    </xsl:template>
    
    <xsl:template match="updateScope">
        <mdml_maintScp>
            <xsl:value-of select="."/>
        </mdml_maintScp>
    </xsl:template>
    
    <xsl:template match="updateScopeDescription">
        <mdml_upScpDesc>
            <xsl:value-of select="MD_ScopeDescription"/>
        </mdml_upScpDesc>
    </xsl:template>
    
    <xsl:template match="maintenanceNote">
        <mdml_maintNote>
            <xsl:value-of select="."/>
        </mdml_maintNote>
    </xsl:template>
    
    <xsl:template match="contact">
        <mdml_maintCont>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </mdml_maintCont>
    </xsl:template>
    
    <xsl:template match="MD_ScopeDescription">
       <xsl:apply-templates select="./attributes"/><!-- attribSet -->
        <xsl:apply-templates select="./features"/><!-- featSet -->
        <xsl:apply-templates select="./featureInstances"/><!-- featIntSet -->
        <xsl:apply-templates select="./attributeInstances"/><!-- attribIntSet -->
        <xsl:apply-templates select="./dataSet"/><!-- datasetSet -->
        <xsl:apply-templates select="./other"/><!-- other -->
    </xsl:template>
    
    <xsl:template match="attributes">
        <mdml_attribSet><xsl:value-of select="."/></mdml_attribSet>
    </xsl:template>
    
    <xsl:template match="features">
        <mdml_featSet><xsl:value-of select="."/></mdml_featSet>
    </xsl:template>
    
    <xsl:template match="featureInstances">
        <mdml_featIntSet><xsl:value-of select="."/></mdml_featIntSet>
    </xsl:template>
    
    <xsl:template match="attributteInstances">
        <mdml_attribIntSet><xsl:value-of select="."/></mdml_attribIntSet>
    </xsl:template>
    
    <xsl:template match="dataSet">
        <mdml_datasetSet><xsl:value-of select="."/></mdml_datasetSet>
    </xsl:template>
    
    <xsl:template match="other">
        <mdml_other><xsl:value-of select="."/></mdml_other>
    </xsl:template>
    
    
    <xsl:template match="MD_BrowseGraphic">
        <xsl:apply-templates select="./fileName"/><!-- bgFileName -->
        <xsl:apply-templates select="./fileDescription"/><!-- bgFileDesc -->
        <xsl:apply-templates select="./fileType"/><!-- bgFileType -->
    </xsl:template>
    
    <xsl:template match="fileName">
        <mdml_bgFileName><xsl:value-of select="."/></mdml_bgFileName>
    </xsl:template>
    
    <xsl:template match="fileDescription">
        <mdml_bgFileDesc><xsl:value-of select="."/></mdml_bgFileDesc>
    </xsl:template>
    
    <xsl:template match="fileType">
        <mdml_bgFileType><xsl:value-of select="."/></mdml_bgFileType>
    </xsl:template>
    
    
    <xsl:template match="MD_Format">
        <xsl:apply-templates select="./name"/><!-- fileName -->
        <xsl:apply-templates select="./version"/><!-- formatVer -->
        <xsl:apply-templates select="./amendmentNumber"/><!-- formatAmdNum -->
        <xsl:apply-templates select="./specification"/><!-- formatSpec -->
        <xsl:apply-templates select="./fileDecompressionTecnique"/><!-- fileDecmTech -->
        <xsl:if test="./formatDistributor">
            <formatDistributorList>
                <xsl:for-each select="./formatDistributor">
                    <xsl:apply-templates select="."/><!-- formatDist -->
                </xsl:for-each>
            </formatDistributorList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="name">
        <mdml_fileName><xsl:value-of select="."/></mdml_fileName>
    </xsl:template>
    
    <xsl:template match="version">
        <mdml_formatVer><xsl:value-of select="."/></mdml_formatVer>
    </xsl:template>
    
    <xsl:template match="amendmentNumber">
        <mdml_formatAmdNum><xsl:value-of select="."/></mdml_formatAmdNum>
    </xsl:template>
    
    <xsl:template match="specification">
        <mdml_formatSpec><xsl:value-of select="."/></mdml_formatSpec>
    </xsl:template>
    
    <xsl:template match="fileDecompressionTechnique">
        <mdml_fileDecmTech><xsl:value-of select="."/></mdml_fileDecmTech>
    </xsl:template>
    
    <xsl:template match="formatDistributor">
        <mdml_formatDist><xsl:apply-templates select="MD_Distributor"/></mdml_formatDist>
    </xsl:template>
    
    
    <xsl:template match="MD_Keywords">
        <xsl:if test="./keyword"><!-- keyword -->
            <keywordList>
                <xsl:for-each select="./keyword">
                    <xsl:apply-templates select="."></xsl:apply-templates>
                </xsl:for-each>
            </keywordList>
        </xsl:if>    
        <xsl:apply-templates select="./type"/><!-- keyTyp -->
        <xsl:apply-templates select="./thesaurusName"/><!-- thesaName -->
    </xsl:template>
    
    <xsl:template match="keyword">
        <mdml_keyword><xsl:value-of select="."/></mdml_keyword>
    </xsl:template>
    
    <xsl:template match="type">
        <mdml_keyTyp><xsl:value-of select="."/></mdml_keyTyp>
    </xsl:template>
    
    <xsl:template match="thesaurusName">
        <mdml_thesaName><xsl:apply-templates select="CI_Citation"/></mdml_thesaName>
    </xsl:template>
    
  
    <xsl:template match="MD_Distributor">
        <xsl:apply-templates select="./distributorContact"/><!-- distorCont -->
        <xsl:if test="distributionOrderProcess"><!-- distorOrdPrc -->
            <distributionOrderProcessList>
                <xsl:for-each select="./distributionOrderProcess">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </distributionOrderProcessList>
        </xsl:if>
        <xsl:if test="./distributorFormat"><!-- distorFormat -->
            <distributorFormatList>
                <xsl:for-each select="./distributorFormat">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </distributorFormatList>
        </xsl:if>
        <xsl:if test="./distributorTransferOptions"><!-- distorTran -->
            <distributorTransferOptionsList>
                <xsl:for-each select="./distributorTransferOptions">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </distributorTransferOptionsList>
        </xsl:if>
    </xsl:template>
  
    <xsl:template match="distributorContact">
        <mdml_distorCont>
            <xsl:apply-templates select="CI_ResponsibleParty"></xsl:apply-templates>
        </mdml_distorCont>
    </xsl:template> 
    
    <xsl:template match="distributionOrderProcess">
        <mdml_distorOrdPrc>
            <xsl:apply-templates select="MD_StandardOrderProcess"/>
        </mdml_distorOrdPrc>
    </xsl:template> 
    
    <xsl:template match="distributorFormat">
        <mdml_distorFormat>
            <xsl:apply-templates select="MD_Format"/>
        </mdml_distorFormat>
    </xsl:template> 
    
    <xsl:template match="distributorTransferOptions">
        <mdml_distorTran>
            <xsl:apply-templates select="MD_DigitalTransferOptions"/>
        </mdml_distorTran>
    </xsl:template> 
  
    <xsl:template match="MD_StandardOrderProcess">
        <xsl:apply-templates select="./fees"/><!-- resFees -->
        <xsl:apply-templates select="./plannedAvailableDateTime"/><!-- planAvDtTm -->
        <xsl:apply-templates select="./orderingInstructions"/><!-- ordInstr -->
        <xsl:apply-templates select="./turnaround"/><!-- ordTurn -->
    </xsl:template>
  
    <xsl:template match="fees">
        <mdml_resFees><xsl:value-of select="."/></mdml_resFees>
    </xsl:template>
  
    <xsl:template match="plannedAvailableDateTime">
        <mdml_planAvDtTm><xsl:value-of select="."/></mdml_planAvDtTm>
    </xsl:template>
    
    <xsl:template match="orderingInstructions">
        <mdml_ordInstr><xsl:value-of select="."/></mdml_ordInstr>
    </xsl:template>
    
    <xsl:template match="turnaround">
        <mdml_ordTurn><xsl:value-of select="."/></mdml_ordTurn>
    </xsl:template>
  
  
    <xsl:template match="MD_DigitalTransferOptions">
        <xsl:apply-templates select="./unitsOfDistribution"/><!-- unitsODist -->
        <xsl:apply-templates select="./transferSize"/><!-- transSize -->
        <xsl:if test="./onLine"><!-- onLineSrc -->
            <onLineList>
                <xsl:for-each select="./onLine">
                    <xsl:apply-templates select="."></xsl:apply-templates>
                </xsl:for-each>
            </onLineList>
        </xsl:if>
        <xsl:apply-templates select="./offLine"/><!-- offLineMed -->
    </xsl:template>
  
    <xsl:template match="unitsOfDistribution">
        <mdml_unitsODist>
            <xsl:value-of select="."/>
        </mdml_unitsODist>
    </xsl:template>
  
    <xsl:template match="transferSize">
        <mdml_transSize>
            <xsl:value-of select="."/>
        </mdml_transSize>
    </xsl:template>
    
    <xsl:template match="onLine">
        <mdml_onLineSrc>
            <xsl:apply-templates select="CI_OnlineResource"/>
        </mdml_onLineSrc>
    </xsl:template>
    
    <xsl:template match="offLine">
        <mdml_offLineMed>
            <xsl:value-of select="MD_Medium"/>
        </mdml_offLineMed>
    </xsl:template>
  
  
    <xsl:template match="MD_usage">
        <xsl:apply-templates select="./specificUsage"/><!-- specUsage -->
        <xsl:apply-templates select="./usageDateTime"/><!-- usageDate -->
        <xsl:apply-templates select="./userDeterminedLimitations"/><!-- usrDetLim -->
        <xsl:if test="./userContactInfo"><!-- usrCntInfo -->
            <userContactInfoList>
                <xsl:for-each select="./userContactInfo">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </userContactInfoList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="specificUsage">
        <mdml_specUsage>
            <xsl:value-of select="."/>
        </mdml_specUsage>
    </xsl:template>
    
    <xsl:template match="usageDateTime">
        <mdml_usageDate>
            <xsl:value-of select="."/>
        </mdml_usageDate>
    </xsl:template>
    
    <xsl:template match="userDeterminedLimitations">
        <mdml_userDetLim>
            <xsl:value-of select="."/>
        </mdml_userDetLim>
    </xsl:template>
    
    <xsl:template match="userContactInfo">
        <mdml_usrCntInfo>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </mdml_usrCntInfo>
    </xsl:template>
    
    
    <xsl:template match="MD_Constraints">
        <xsl:if test="./useLimitation"><!-- useLimit -->
            <useLimitationList>
                <xsl:for-each select="./useLimitation">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </useLimitationList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="useLimitation">
        <mdml_useLimit>
            <xsl:value-of select="."/>
        </mdml_useLimit>
    </xsl:template>
    
    
    <xsl:template match="MD_Medium">
        <xsl:apply-templates select="./name"/><!-- medName -->
        <xsl:if test="./density"><!-- medDensity -->
            <densityList>
                <xsl:for-each select="./density">
                    <xsl:apply-templates select="."/>            
                </xsl:for-each>
            </densityList>
        </xsl:if>
        <xsl:apply-templates select="./densityUnits"/><!-- medDenUnits -->
        <xsl:apply-templates select="./volumes"/><!-- medVol -->
        <xsl:if test="./mediumFormat"><!-- medFormat -->
            <mediumFormatList>
                <xsl:for-each select="./mediumFormat">
                    <xsl:apply-templates select="."/>            
                </xsl:for-each>
            </mediumFormatList>
        </xsl:if>
        <xsl:apply-templates select="mediumNote"/><!-- medNote -->
    </xsl:template>
    
    <xsl:template match="name">
        <mdml_medName>
            <xsl:value-of select="."/>
        </mdml_medName>
    </xsl:template>
    
    <xsl:template match="density">
        <mdml_medDensity>
            <xsl:value-of select="."/>
        </mdml_medDensity>
    </xsl:template>
    
    <xsl:template match="densityUnits">
        <mdml_medDenUnits>
            <xsl:value-of select="."/>
        </mdml_medDenUnits>
    </xsl:template>
    
    <xsl:template match="volumes">
        <mdml_medVol>
            <xsl:value-of select="."/>
        </mdml_medVol>
    </xsl:template>
    
    <xsl:template match="mediumFormat">
        <mdml_medFormat>
            <xsl:value-of select="."/>
        </mdml_medFormat>
    </xsl:template>
    
    <xsl:template match="mediumNote">
        <mdml_medNote>
            <xsl:value-of select="."/>
        </mdml_medNote>
    </xsl:template>
    
    
    <xsl:template match="MD_AggregateInformation">
        <xsl:apply-templates select="./aggregateDataSetName"/><!-- aggrDSName -->
        <xsl:apply-templates select="./aggregateDataSetIdentifier"/><!-- aggrDSIdent -->
        <xsl:apply-templates select="./associationType"/><!-- assocType -->
        <xsl:apply-templates select="./initiativeType"/><!-- initType -->
    </xsl:template>
    
    <xsl:template match="aggregateDataSetName">
        <mdml_aggrDSName>
            <xsl:apply-templates select="CI_Citation"/>
        </mdml_aggrDSName>
    </xsl:template>
    
    <xsl:template match="aggregateDataSetIdentifier">
        <mdml_aggrDSIdent>
            <xsl:apply-templates select="MD_identifier"/>
        </mdml_aggrDSIdent>
    </xsl:template>
    
    <xsl:template match="associationType">
        <mdml_assocType>
            <xsl:value-of select="."/>
        </mdml_assocType>
    </xsl:template>
    
    <xsl:template match="initiativeType">
        <mdml_initType>
            <xsl:value-of select="."/>
        </mdml_initType>
    </xsl:template>
    
    
    <xsl:template match="MD_Identifier">
        <xsl:apply-templates select="./authority"/><!-- identAuth -->
        <xsl:apply-templates select="./code"/><!-- identCode -->
    </xsl:template>
    
    <xsl:template match="authority">
        <mdml_identAuth><xsl:apply-templates select="CI_Citation"/></mdml_identAuth>
    </xsl:template>
    
    <xsl:template match="code">
        <mdml_identCode><xsl:value-of select="."/></mdml_identCode>
    </xsl:template>
    
      
    <xsl:template match="MD_FeatureCatalogueDescription">
        <xsl:apply-templates select="./complianceCode"/><!-- compCode -->
        <xsl:if test="language"><!-- catLang -->
            <languageList>
                <xsl:for-each select="./language">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </languageList>
        </xsl:if>
        <xsl:apply-templates select="./includedWithDataset"/><!-- incWithDS -->
        <xsl:if test="./featureTypes"><!-- catFetTyps -->
            <featureTypesList>
                <xsl:for-each select="./featureTypes">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </featureTypesList>
        </xsl:if>
        <xsl:if test="./featureCatalogueCitation"><!-- catCitation -->
            <featureCatalogueCitationList>
                <xsl:for-each select="./featureCatalogueCitation">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </featureCatalogueCitationList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="complianceCode">
        <mdml_compCode><xsl:value-of select="."/></mdml_compCode>
    </xsl:template>
    
    <xsl:template match="language">
        <mdml_catLang><xsl:value-of select="."/></mdml_catLang>
    </xsl:template>
    
    <xsl:template match="includedWithDataset">
        <mdml_incWithDS><xsl:value-of select="."/></mdml_incWithDS>
    </xsl:template>
    
    <xsl:template match="featureTypes">
        <mdml_catFetTyps><xsl:value-of select="."/></mdml_catFetTyps>
    </xsl:template>
    
    <xsl:template match="featureCatalogueCitation">
        <mdml_catCitation><xsl:value-of select="."/></mdml_catCitation>
    </xsl:template>
    
    
    <xsl:template match="MD_Distribution">
        <xsl:if test="distributionFormat"><!-- distFormat -->
            <distributionFormatList>
                <xsl:for-each select="distributionFormat">
                    <xsl:apply-templates select="."/>    
                </xsl:for-each>
            </distributionFormatList>    
        </xsl:if>
        <xsl:if test="distributor"><!-- distributor -->
            <distributorList>
                <xsl:for-each select="distributor">
                    <xsl:apply-templates select="."/>    
                </xsl:for-each>
            </distributorList>    
        </xsl:if>
        <xsl:if test="transferOptions"><!-- distTranOps -->
            <transferOptionsList>
                <xsl:for-each select="transferOptions">
                    <xsl:apply-templates select="."/>    
                </xsl:for-each>
            </transferOptionsList>    
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="distributionFormat">
        <mdml_distFormat>
            <xsl:apply-templates select="MD_Format"/>
        </mdml_distFormat>
    </xsl:template>
    
    <xsl:template match="distributor">
        <mdml_distributor>
            <xsl:apply-templates select="MD_Distributor"/>
        </mdml_distributor>
    </xsl:template>
    
    <xsl:template match="transferOptions">
        <mdml_distTransOps>
            <xsl:apply-templates select="MD_DigitalTransferOptions"/>
        </mdml_distTransOps>
    </xsl:template>
    
    <xsl:template match="MD_ContentInformation">
        <xsl:if test="MD_FeatureCatalogueDescription">
            <xsl:apply-templates select="MD_FeatureCatalogueDescription"/>
        </xsl:if>
        <xsl:if test="MD_CoverageDescription">
            <xsl:apply-templates select="MD_CoverageDescription"/>
        </xsl:if>
        <xsl:if test="MD_ImageDescription">
            <xsl:apply-templates select="MD_ImageDescription"/>
        </xsl:if>
    </xsl:template>
    
    
    <xsl:template match="MD_CoverageDescription">
        <xsl:apply-templates select="./attributeDescription"/><!-- attDesc -->
        <xsl:apply-templates select="contentType"/><!-- contentTyp -->
        <xsl:if test="./dimension"><!-- covDim -->
            <dimensionList>
                <xsl:for-each select="./dimension">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </dimensionList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="attributeDescription">
        <mdml_attDesc><xsl:value-of select="."/></mdml_attDesc>
    </xsl:template>
    
    <xsl:template match="contentType">
        <mdml_contentTyp><xsl:value-of select="."/></mdml_contentTyp>
    </xsl:template>
    
    <xsl:template match="dimension">
        <mdml_covDim><xsl:apply-templates select="MD_RangeDimension"/></mdml_covDim>
    </xsl:template>
    
    
    <xsl:template match="MD_RangeDimension">
        <xsl:apply-templates select="./sequenceIdentifier"/><!-- seqID -->
        <xsl:apply-templates select="./descriptor"/><!-- dimDescrp -->
    </xsl:template>
    
    
    <xsl:template match="sequenceIdentifier">
        <mdml_seqID><xsl:value-of select="."/></mdml_seqID>
    </xsl:template>
    
    <xsl:template match="descriptor">
        <mdml_dimDescrp><xsl:value-of select="."/></mdml_dimDescrp>
    </xsl:template>
    
    
    <xsl:template match="MD_ImageDescription">
        <xsl:apply-templates select="MD_CoverageDescription"/>
        <xsl:apply-templates select="./illuminationElevationAngle"/><!-- illElevAng -->
        <xsl:apply-templates select="./illuminationAzimuthAngle"/><!-- illAziAng -->
        <xsl:apply-templates select="./imagingCondition"/><!-- imagCond -->
        <xsl:apply-templates select="./imageQualityCode"/><!-- imagQuCode -->
        <xsl:apply-templates select="./cloudCoverPercentage"/><!-- cloudCovPer -->
        <xsl:apply-templates select="./processingLevelCode"/><!-- prcTypCde -->
        <xsl:apply-templates select="./compressionGenerationQuantity"/><!-- cmpGenQuan -->
        <xsl:apply-templates select="./triangulationIndicator"/><!-- trianInd -->
        <xsl:apply-templates select="./radiometricCalibrationDataAvailability"/><!-- radCalDatAv -->
        <xsl:apply-templates select="./cameraCalibrationInformationAvailability"/><!-- camCalInAv -->
        <xsl:apply-templates select="./filmDistortionInformationAvailability"/><!-- filmDistInAv -->
        <xsl:apply-templates select="./lensDistortionInformationAvailability"/><!-- lensDistInAv -->
    </xsl:template>
    
    <xsl:template match="illuminationElevationAngle">
        <mdml_illElevAng>
            <xsl:value-of select="."/>
        </mdml_illElevAng>
    </xsl:template>
    
    <xsl:template match="illuminationAzimuthAngle">
        <mdml_illAziAng>
            <xsl:value-of select="."/>
        </mdml_illAziAng>
    </xsl:template>
    
    <xsl:template match="imagingCondition">
        <mdml_imagCond>
            <xsl:value-of select="."/>
        </mdml_imagCond>
    </xsl:template>
    
    <xsl:template match="imagingQualityCode">
        <mdml_imagQuCode>
            <xsl:apply-templates select="MD_Identifier"/>
        </mdml_imagQuCode>
    </xsl:template>
    
    <xsl:template match="cloudCoverPercentage">
        <mdml_cloudCovPer>
            <xsl:value-of select="."/>
        </mdml_cloudCovPer>
    </xsl:template>
    
    <xsl:template match="processingLevelCode">
        <mdml_prcTypCode>
            <xsl:apply-templates select="MD_Identifier"/>
        </mdml_prcTypCode>
    </xsl:template>
    
    <xsl:template match="compressionGenerationQuantity">
        <mdml_cmpGenQuan>
            <xsl:value-of select="."/>
        </mdml_cmpGenQuan>
    </xsl:template>
    
    <xsl:template match="triangulationIndicator">
        <mdml_trianInd>
            <xsl:value-of select="."/>
        </mdml_trianInd>
    </xsl:template>
    
    <xsl:template match="radiometricCalibrationDataAvailability">
        <mdml_radCalDatAv>
            <xsl:value-of select="."/>
        </mdml_radCalDatAv>
    </xsl:template>
    
    <xsl:template match="cameraCalibrationInformationAvailability">
        <mdml_camCalInAv>
            <xsl:value-of select="."/>
        </mdml_camCalInAv>
    </xsl:template>
    
    
    <xsl:template match="filmDistortionInformationAvailability">
        <mdml_filmDistInAv>
            <xsl:value-of select="."/>
        </mdml_filmDistInAv>
    </xsl:template>
    
    <xsl:template match="lensDistortionInformationAvailability">
        <mdml_lensDistInAv>
            <xsl:value-of select="."/>
        </mdml_lensDistInAv>
    </xsl:template>
    
    
    <xsl:template match="EX_Extent">
        <xsl:apply-templates select="./description"/><!-- exDesc -->
        <xsl:if test="./geographicElement"><!-- geoEle -->
            <geographicElementList>
                <xsl:for-each select="./geographicElement">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </geographicElementList>
        </xsl:if>
        <xsl:if test="./temporalElement"><!-- tempEle -->
            <temporalElementList>
                <xsl:for-each select="./temporalElement">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </temporalElementList>
        </xsl:if>
        <xsl:if test="./verticalElement"><!-- vertEle -->
            <verticalElementList>
                <xsl:for-each select="./verticalElement">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </verticalElementList>
        </xsl:if>       
    </xsl:template>
    
    <xsl:template match="description">
        <mdml_extDesc><xsl:value-of select="."/></mdml_extDesc>
    </xsl:template
>
        
    <xsl:template match="geographicElement">
        <mdml_geoEle>
            <xsl:apply-templates select="EX_GeographicExtent | EX_GeographicBoundingBox | EX_BoundingPolygon | EX_GeographicDescription"/>
        </mdml_geoEle>
    </xsl:template>
    
    <xsl:template match="temporalElement">
        <mdml_tempEle>
            <xsl:apply-templates select="EX_TemporalExtent"/>
        </mdml_tempEle>
    </xsl:template>
    
    <xsl:template match="verticalElement">
        <mdml_vertEle>
            <xsl:apply-templates select="EX_VerticalExtent"/>
        </mdml_vertEle>
    </xsl:template>
    
    <xsl:template match="MD_RepresentativeFraction">
        <xsl:apply-templates select="./denominator"/><!-- rfDenom -->
    </xsl:template>
    
    <xsl:template match="denominator">
        <mdml_rfDenom>
            <xsl:value-of select="."/>
        </mdml_rfDenom>
    </xsl:template>
    
    
    <xsl:template match="MD_ReferenceSystem">
        <xsl:apply-templates select="./referenceSystemIdentifier"/><!-- refSysId -->
    </xsl:template>
    
    <xsl:template match="referenceSystemIdentifier">
        <mdml_refSysId>
            <xsl:apply-templates select="RS_Identifier"/>
        </mdml_refSysId>
    </xsl:template>
    
    
    <xsl:template match="MD_ApplicationSchemaInformation">
        <xsl:apply-templates select="./name"/><!-- asName -->
        <xsl:apply-templates select="./schemaLanguage"/><!-- asSchLang -->
        <xsl:apply-templates select="./constraintLanguage"/><!-- asCstLang -->
        <xsl:apply-templates select="./schemaAscii"/><!-- asAscii -->
        <xsl:apply-templates select="./graphicsFile"/><!-- asGraFile -->
        <xsl:apply-templates select="./softwareDevelopmentFile"/><!-- asSwDevFile -->
        <xsl:apply-templates select="./softwareDevelopmentFileFormat"/><!-- asSwDevFiFt -->
    </xsl:template>
    
    <xsl:template match="name">
        <mdml_asName>
            <xsl:apply-templates select="CI_Citation"/>
        </mdml_asName>
    </xsl:template>
    
    <xsl:template match="schemaLanguage">
        <mdml_asSchLang>
            <xsl:value-of select="."/>
        </mdml_asSchLang>
    </xsl:template>
    
    <xsl:template match="constraintLanguage">
        <asCstLang>
            <xsl:value-of select="."/>
        </asCstLang>
    </xsl:template>
    
    <xsl:template match="schemaAscii">
        <mdml_asAscii>
            <xsl:value-of select="."/>
        </mdml_asAscii>
    </xsl:template>
    
    <xsl:template match="graphicsFile">
        <mdml_asGraFile>
            <xsl:value-of select="."/>
        </mdml_asGraFile>
    </xsl:template>
    
    <xsl:template match="softwareDevelopmentFile">
        <mdml_asSwDevFile>
            <xsl:value-of select="."/>
        </mdml_asSwDevFile>
    </xsl:template>
    
    <xsl:template match="softwareDevelopmentFileFormat">
        <mdml_asSwDevFiFt>
            <xsl:value-of select="."/>
        </mdml_asSwDevFiFt>
    </xsl:template>
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    <!-- ____________________ MD's ____________________________________ -->
    

    <!-- ____________________ RS's ____________________________________ -->
    
    <xsl:template match="RS_Identifier">
        <xsl:apply-templates select="./codeSpace"/><!-- identCodeSpace -->
        <xsl:apply-templates select="./version"/><!-- identVrsn -->
    </xsl:template>
    
    <xsl:template match="codeSpace">
        <mdml_identCodeSpace>
            <xsl:value-of select="."/>
        </mdml_identCodeSpace>
    </xsl:template>
    
    <xsl:template match="version">
        <mdml_identVrsn>
            <xsl:value-of select="."/>
        </mdml_identVrsn>
    </xsl:template>
    
    
    <!-- ____________________ RS's ____________________________________ -->
    
    
    
    
    
    <!-- ____________________ EX 's ____________________________________ -->

    <xsl:template match="EX_GeographicExtent">
        <xsl:apply-templates select="./extentTypeCode"/><!-- exTypCode -->
        <xsl:if test="EX_BoundingPolygon">
            <xsl:apply-templates select="."/>
        </xsl:if>
        <xsl:if test="EX_GeographicBoundingBox">
            <xsl:apply-templates select="."/>
        </xsl:if>
        <xsl:if test="EX_GeographicDescription">
            <xsl:apply-templates select="."/>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="extentTypeCode">
        <mdml_exTypCode>
            <xsl:value-of select="."/>
        </mdml_exTypCode>
    </xsl:template>
    
    
    <xsl:template match="EX_BoundingPolygon">
        <xsl:if test="./polygon"><!-- polygon -->
            <polygonList>
                <xsl:for-each select="./polygon">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </polygonList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="polygon">
        <mdml_polygon>
            <xsl:value-of select="."/>
        </mdml_polygon>
    </xsl:template>
    
    
    <xsl:template match="EX_GeographicBoundingBox">
        <xsl:apply-templates select="./westBoundLongitude"/><!-- westBL -->
        <xsl:apply-templates select="./eastBoundLongitude"/><!-- eastBL -->
        <xsl:apply-templates select="./southBoundLatitude"/><!-- southBL -->
        <xsl:apply-templates select="./northBoundLatitude"/><!-- northBL -->
    </xsl:template>
    
    <xsl:template match="westBoundLongitude">
        <mdml_westBL>
            <xsl:value-of select="."/>
        </mdml_westBL>
    </xsl:template>
    
    <xsl:template match="eastBoundLongitude">
        <mdml_eastBL>
            <xsl:value-of select="."/>
        </mdml_eastBL>
    </xsl:template>
    
    <xsl:template match="southBoundLatitude">
        <mdml_southBL>
            <xsl:value-of select="."/>
        </mdml_southBL>
    </xsl:template>
    
    <xsl:template match="northBoundLatitude">
        <mdml_northBL>
            <xsl:value-of select="."/>
        </mdml_northBL>
    </xsl:template>
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    <xsl:template match="EX_GeographicDescription">
        <xsl:apply-templates select="./geographicIdentifier"/><!-- geoId -->
    </xsl:template>
    
    <xsl:template match="geographicIdentifier">
        <mdml_geoId>
            <xsl:value-of select="."/>
        </mdml_geoId>
    </xsl:template>
    
    
    <xsl:template match="EX_TemporalExtent">
        <xsl:apply-templates select="./extent"/><!--exTemp -->
        <xsl:if test="EX_SpatialTemporalExtent">
            <xsl:apply-templates select="."/>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="extent">
        <mdml_exTemp>
            <xsl:value-of select="."/>
        </mdml_exTemp>
    </xsl:template>
    
    
    <xsl:template match="EX_SpatialTemporalExtent">
        <xsl:if test="./spatialExtent">
            <spatialExtentList>
                <xsl:for-each select="./spatialExtent">
                    <xsl:apply-templates select="."/><!-- exSpat -->
                </xsl:for-each>
            </spatialExtentList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="spatialExtent">
        <mdml_exSpat>
            <xsl:value-of select="."/>
        </mdml_exSpat>
    </xsl:template>
    
    
    <xsl:template match="EX_VerticalExtent">
        <xsl:apply-templates select="./minimumValue"/><!-- vertMinVal -->
        <xsl:apply-templates select="./maximumValue"/><!-- vertMaxVal -->
        <xsl:apply-templates select="./unitOfMeasure"/><!-- vertUoM -->
        <xsl:apply-templates select="./verticalDatum"/><!-- vertDatum -->
    </xsl:template>
    
    <xsl:template match="minimumValue">
        <mdml_vertMinVal>
            <xsl:value-of select="."/>
        </mdml_vertMinVal>
    </xsl:template>
    
    <xsl:template match="maximumValue">
        <mdml_vertMaxVal>
            <xsl:value-of select="."/>
        </mdml_vertMaxVal>
    </xsl:template>
    
    <xsl:template match="unitOfMeasure">
        <mdml_vertUoM>
            <xsl:value-of select="."/>
        </mdml_vertUoM>
    </xsl:template>
    
    <xsl:template match="verticalDatum">
        <mdml_vertDatum>
            <xsl:value-of select="."/>
        </mdml_vertDatum>
    </xsl:template>
    

    <!-- Falta implementar TM_Primitive (ISO 19108) y SC_VerticalDatum (ISO 19111) -->

    <!-- ____________________ EX 's ____________________________________ -->
    


    <!-- ____________________ LI 's ____________________________________ -->
    
    <xsl:template match="LI_Lineage">
        <xsl:apply-templates select="./statement"/><!-- statement -->
        <xsl:if test="./processStep"><!-- prcStep -->
            <processStepList>
                <xsl:for-each select="./processStep">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </processStepList>
        </xsl:if>
        <xsl:if test="./source"><!-- dataSource -->
            <sourceList>
                <xsl:for-each select="./source">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </sourceList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="statement">
        <mdml_statement>
            <xsl:value-of select="."/>
        </mdml_statement>
    </xsl:template>
    
    <xsl:template match="processStep">
        <mdml_prcStep>
            <xsl:apply-templates select="LI_ProcessStep"/>
        </mdml_prcStep>
    </xsl:template>
    
    <xsl:template match="source">
        <mdml_dataSource>
            <xsl:apply-templates select="LI_Source"/>
        </mdml_dataSource>
    </xsl:template>
    
    
    <xsl:template match="LI_ProcessStep">
        <xsl:apply-templates select="./description"/><!-- stepDesc -->
        <xsl:apply-templates select="./rationale"/><!-- stepRat -->
        <xsl:apply-templates select="./dateTime"/><!-- stepDateTm -->
        <xsl:if test="./processor"><!-- stepProc -->
            <processorList>
                <xsl:for-each select="./processor">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </processorList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="description">
        <mdml_stepDesc>
            <xsl:value-of select="."/>
        </mdml_stepDesc>
    </xsl:template>
    
    <xsl:template match="rationale">
        <mdml_stepRat>
            <xsl:value-of select="."/>
        </mdml_stepRat>
    </xsl:template>
    
    <xsl:template match="dateTime">
        <mdml_stepDateTm>
            <xsl:value-of select="."/>
        </mdml_stepDateTm>
    </xsl:template>
    
    <xsl:template match="processor">
        <mdml_stepProc>
            <xsl:apply-templates select="CI_ResponsibleParty"/>
        </mdml_stepProc>
    </xsl:template>
    
    
    <xsl:template match="LI_Source">
        <xsl:apply-templates select="./description"/><!-- srcDesc -->
        <xsl:apply-templates select="./scaleDenominator"/><!-- srcScale -->
        <xsl:apply-templates select="./sourceReferenceSystem"/><!-- srcRefSys -->
        <xsl:apply-templates select="./sourceCitation"/><!-- srcCitatn -->
        <xsl:if test="./sourceExtent"><!-- srcExt -->
            <sourceExtentList>
                <xsl:for-each select="./sourceExtent">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </sourceExtentList>
        </xsl:if>
        <xsl:if test="./sourceStep"><!-- srcStep -->
            <sourceStepList>
                <xsl:for-each select="./sourceStep">
                    <xsl:apply-templates select="."/>
                </xsl:for-each>
            </sourceStepList>
        </xsl:if>
    </xsl:template>
    
    <xsl:template match="description">
        <mdml_srcDesc>
            <xsl:value-of select="."/>
        </mdml_srcDesc>
    </xsl:template>
    
    <xsl:template match="scaleDenominator">
        <mdml_srcScale>
            <xsl:apply-templates select="MD_RepresentativeFraction"/>
        </mdml_srcScale>
    </xsl:template>
    
    <xsl:template match="sourceReferenceSystem">
        <mdml_srcRefSys>
            <xsl:apply-templates select="MD_ReferenceSystem"/>
        </mdml_srcRefSys>
    </xsl:template>
    
    <xsl:template match="sourceCitation">
        <mdml_srcCitatn>
            <xsl:apply-templates select="CI_Citation"/>
        </mdml_srcCitatn>
    </xsl:template>
    
    <xsl:template match="sourceExtent">
        <mdml_srcExt>
            <xsl:apply-templates select="EX_Extent"/>
        </mdml_srcExt>
    </xsl:template>
    
    <xsl:template match="sourceStep">
        <mdml_srcStep>
            <xsl:apply-templates select="LI_ProcessStep"></xsl:apply-templates>
        </mdml_srcStep>
    </xsl:template>
    
    <!-- ____________________ LI 's ____________________________________ -->
    

    <xsl:template match="phone">
        <mdml_cntPhone>
            <xsl:apply-templates select="CI_Telephone"/>
        </mdml_cntPhone>
    </xsl:template>
    
    <xsl:template match="address">
        <mdml_cntAddress>
        	<xsl:apply-templates select="CI_Address"/>
        </mdml_cntAddress>
    </xsl:template>
    
    
    <xsl:template match="onlineResource">
        <mdml_cntOnlineRes>
            <xsl:apply-templates select="CI_OnlineResource"/>
        </mdml_cntOnlineRes>
    </xsl:template>
    
    
    
    <xsl:template match="dateStamp">
        <mdml_mdDateSt><xsl:value-of select="."/></mdml_mdDateSt>
    </xsl:template>
    
    <xsl:template match="metadataStandardName">
        <mdml_mdStanName><xsl:value-of select="."/></mdml_mdStanName>
    </xsl:template>
    
    <xsl:template match="metadataStandardVersion">
        <mdml_mdStanVer><xsl:value-of select="."/></mdml_mdStanVer>
    </xsl:template>
    
    <xsl:template match="dataSetURI">
        <mdml_dataSetURI><xsl:value-of select="."/></mdml_dataSetURI>
    </xsl:template>
    
    <xsl:template match="metadataExtensionInfo">
        <mdml_mdExtInfo><xsl:value-of select="."/></mdml_mdExtInfo>
    </xsl:template>
    
    <xsl:template match="identificationInfo">
        <mdml_dataIdInfo>
            <xsl:apply-templates select="MD_DataIdentification"/>
        </mdml_dataIdInfo>
    </xsl:template>
    
    <xsl:template match="contentInfo">
        <mdml_contInfo><xsl:apply-templates select="MD_FeatureCatalogueDescription | MD_ImageDescription | MD_CoverageDescription"/></mdml_contInfo>
    </xsl:template>
    
    
    <xsl:template match="distributionInfo">
        <mdml_distInfo><xsl:apply-templates select="MD_Distribution"/></mdml_distInfo>
    </xsl:template>
    
    
    <xsl:template match="dataQualityInfo">
        <mdml_dqInfo>
            <xsl:apply-templates select="DQ_DataQuality"/>
        </mdml_dqInfo>
    </xsl:template>
        
    <xsl:template match="portrayalCatalogueInfo">
        <mdml_porCatInfo>
            <xsl:apply-templates select="MD_PortrayalCatalogueReference"/>
        </mdml_porCatInfo>
    </xsl:template>
    
    <xsl:template match="metadataConstraints">
        <mdml_mdConst>
            <xsl:apply-templates select="MD_Constraints"/>
        </mdml_mdConst>
    </xsl:template>
        
    <xsl:template match="applicationSchemaInfo">
        <mdml_appSchInfo>
            <xsl:apply-templates select="MD_ApplicationSchemaInformation"/>
        </mdml_appSchInfo>
    </xsl:template>
        
    <xsl:template match="metadataMaintenance">
        <mdml_mdMaint>
            <xsl:apply-templates select="MD_MaintenanceInformation"/>
        </mdml_mdMaint>
    </xsl:template>
        
    <xsl:template match="spatialRepresentationInfo">
        <mdml_spatRepInfo>
            <xsl:apply-templates select="MD_SpatialRepresentation"/>
        </mdml_spatRepInfo>
    </xsl:template>    
    
    <xsl:template match="referenceSystemInfo">
        <mdml_refSysInfo>
            <xsl:apply-templates select="MD_ReferenceSystem"/>
        </mdml_refSysInfo>
    </xsl:template>
    
    
    
    
    <!-- MD_ApplicationSchemaInformation, MD_SpatialRepresentation, MD_MetadataExtensionInformation... -->
    
    
    
    
    
    
    
    
    
    
    
    
    
        
    
    <xsl:template match="scope">
        <mdml_dqScope>
            <xsl:apply-templates select="DQ_Scope"/>
        </mdml_dqScope>
    </xsl:template>
    
    
 <xsl:template match="report">
        <mdml_dqReport>
     	<xsl:apply-templates select="DQ_Element"/>
        </mdml_dqReport>
    </xsl:template>

    <xsl:template match="lineage">
        <mdml_dataLineage>
     	<xsl:apply-templates select="LI_Lineage"/>
        </mdml_dataLineage>
    </xsl:template>
    
    
     <xsl:template match="level">
        <mdml_scpLvl>
     	<xsl:value-of select="/."/>
        </mdml_scpLvl>
    </xsl:template>
 
    <xsl:template match="extent">
        <mdml_scpExt><xsl:apply-templates select="EX_Extent"/></mdml_scpExt>
    </xsl:template>

    <xsl:template match="levelDescription">
        <mdml_scpLvlDesc><xsl:value-of select="."/></mdml_scpLvlDesc>    
    </xsl:template>
    
   
    
    <xsl:template match="nameOfMeasure">
        <mdml_measName><xsl:value-of select="."/></mdml_measName>
    </xsl:template>
    
    <xsl:template match="measureIdentification">
        <mdml_measId><xsl:value-of select="."/></mdml_measId>
    </xsl:template>
    
    <xsl:template match="measureDescription">
       <mdml_measDesc><xsl:value-of select="."/></mdml_measDesc>
    </xsl:template>
    
    <xsl:template match="evaluationMethodType">
        <mdml_evalMethType><xsl:value-of select="."/></mdml_evalMethType>
    </xsl:template>

    <xsl:template match="evaluationProcedure">
        <mdml_evalProc>
        	<xsl:apply-templates select="CI_Citation"/>
        </mdml_evalProc>
    </xsl:template>
        
    <xsl:template match="dateTime">
        <mdml_measDateTm><xsl:value-of select="."/></mdml_measDateTm>
    </xsl:template>
    
    <xsl:template match="result">
        <mdml_measResult><xsl:value-of select="."/></mdml_measResult>
    </xsl:template>
        
        
        
 </xsl:stylesheet>   
