<?xml version="1.0" encoding="iso-8859-1" ?>

<xsl:stylesheet version="2.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	xmlns:fn="http://www.w3.org/2005/xpath-functions"
	xmlns:xdt="http://www.w3.org/2005/xpath-datatypes"
	xmlns:err="http://www.w3.org/2005/xqt-errors"
	exclude-result-prefixes="xs xdt err fn">
	<xsl:output method="xml" indent="yes"/>	
	<xsl:template match="mdml_metadata">
		<Metadata>
			<xsl:apply-templates select="./mdml_mdFileID"/>
			<xsl:apply-templates select="./mdLang/mdml_mdLang"/>
			<xsl:apply-templates select="./mdChar/mdml_mdChar"/>
			<xsl:apply-templates select="./mdml_mdContact"/>
			<xsl:apply-templates select="./mdml_mdDateSt"/>
			<xsl:apply-templates select="./mdml_mdStanName"/>
			<xsl:apply-templates select="./mdml_mdStanVer"/>
			<distInfo>
				<xsl:apply-templates select="./distInfo/distTranOps"/>
			</distInfo>
			<dataIdInfo>
				<xsl:apply-templates select="./dataIdInfo/idCitation"/>
				<xsl:apply-templates select="./dataIdInfo/mdml_idAbs"/>
				<xsl:apply-templates select="./dataIdInfo/mdml_idPoc"/>
				<xsl:apply-templates select="./distInfo/mdml_dsFormat"/>
				<xsl:apply-templates select="./dataIdInfo/spatRpType"/>
				<xsl:apply-templates select="./dataIdInfo/mdml_dataScale"/>
				<xsl:apply-templates select="./dataIdInfo/dataLang"/>
				<xsl:apply-templates select="./dataIdInfo/dataChar"/>
				<xsl:apply-templates select="./dataIdInfo/tpCat"/>
				<xsl:apply-templates select="./geoBox"/>
				<xsl:apply-templates select="./dataExt/tempEle/TempExtent/mdml_exTemp/mdml_TM_GeometricPrimitive/mdml_TM_Period"/>
			</dataIdInfo>
			<dqInfo>
				<xsl:apply-templates select="./dqInfo/dataLineage"/>	
			</dqInfo>
			<refSysInfo>
				<xsl:apply-templates select="./mdml_refSysInfo"/> 
			</refSysInfo>	
		</Metadata>
	</xsl:template>
	
	
	
	<xsl:template match="mdml_mdFileID">
		<mdFileID><xsl:value-of select="."/></mdFileID>
	</xsl:template>

	<xsl:template match="mdml_mdLang">
		<mdLang>
			<xsl:element name="languageCode">
				<xsl:attribute name="value">
					<xsl:value-of select="@value"/>
				</xsl:attribute>
			</xsl:element>
		</mdLang>
	</xsl:template>
	
	<xsl:template match="mdml_mdChar">
		<mdChar>
			<xsl:element name="CharSetCd">
				<xsl:attribute name="value">
					<xsl:value-of select="@value"/>
				</xsl:attribute>
			</xsl:element>
		</mdChar>
	</xsl:template>
	
	
	<xsl:template match="mdml_mdContact">
		<mdContact>
			<rpIndName><xsl:value-of select="./mdml_rpIndName"/></rpIndName>
			<rpOrgName><xsl:value-of select="./mdml_rpOrgName"/></rpOrgName>
			<rpPosName><xsl:value-of select="./mdml_rpPosName"/></rpPosName>
			<rpCntInfo><xsl:apply-templates select="./mdml_rpCntInfo"/></rpCntInfo>
			<role>
				<xsl:element name="RoleCd">
					<xsl:attribute name="value">
						<xsl:value-of select="./role/mdml_role/@value"/>
					</xsl:attribute>
				</xsl:element>
			</role>
		</mdContact>
	</xsl:template>


	<xsl:template match="mdml_rpIndName">
		<rpIndName>
			<xsl:value-of select="."/>
		</rpIndName>
	</xsl:template>	
	
	
	
	
	<xsl:template match="mdml_rpOrgName">
		<rpOrgName>
			<xsl:value-of select="."/>
		</rpOrgName>
	</xsl:template>
	
	<xsl:template match="mdml_rpPosName">
		<rpPosName>
			<xsl:value-of select="."/>
		</rpPosName>
	</xsl:template>
	
	<xsl:template match="mdml_role">
		<role>
			<xsl:element name="RoleCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</role>
	</xsl:template>
	
	<xsl:template match="mdml_rpCntInfo">
			<xsl:apply-templates select="mdml_cntPhone"/>
			<xsl:apply-templates select="mdml_cntAddress"/>
			<xsl:apply-templates select="mdml_cntOnlineRes"/>
			<xsl:apply-templates select="mdml_cntHours"/>
			<xsl:apply-templates select="mdml_cntInstr"/>
	</xsl:template>
	
	<xsl:template match="mdml_cntPhone">
		<cntPhone>
			<xsl:apply-templates select="mdml_voiceNum"/>
			<xsl:apply-templates select="mdml_faxNum"/>
		</cntPhone>
	</xsl:template>
	
	<xsl:template match="mdml_voiceNum">
		<voiceNum>
			<xsl:value-of select="./@value"/>
			<xsl:value-of select="."/>
		</voiceNum>
	</xsl:template>
	
	
	<xsl:template match="mdml_faxNum">
		<faxNum>
			<xsl:value-of select="./@value"/>
			<xsl:value-of select="."/>
		</faxNum>
	</xsl:template>
	
	<xsl:template match="mdml_cntAddress">
		<cntAddress>
			<xsl:apply-templates select="mdml_delPoint"/>
			<xsl:apply-templates select="mdml_city"/>
			<xsl:apply-templates select="mdml_adminArea"/>
			<xsl:apply-templates select="mdml_postCode"/>
			<xsl:apply-templates select="mdml_country"/>
			<xsl:apply-templates select="mdml_eMailAdd"/>
		</cntAddress>
	</xsl:template>
	
	<xsl:template match="mdml_delPoint">
		<delPoint>
			<xsl:value-of select="./@value"/>
			<xsl:value-of select="."/>
		</delPoint>
	</xsl:template>
	
	<xsl:template match="mdml_city">
		<city>
			<xsl:value-of select="."/>
		</city>
	</xsl:template>
	
	
	<xsl:template match="mdml_adminArea">
		<adminArea>
			<xsl:value-of select="."/>
		</adminArea>
	</xsl:template>
	
	
	<xsl:template match="mdml_postCode">
		<postCode>
			<xsl:value-of select="."/>
		</postCode>
	</xsl:template>
	
	<xsl:template match="mdml_country">
		<country>
			<xsl:value-of select="./@value"/>
		</country>
	</xsl:template>
	
	
	<xsl:template match="mdml_eMailAdd">
		<eMailAdd>
			<xsl:value-of select="./@value"/>
			<xsl:value-of select="."/>
		</eMailAdd>
	</xsl:template>
	
	
	
	<xsl:template match="mdml_cntOnlineRes">
		<cntOnLineRes>
			<xsl:apply-templates select="mdml_linkage"/>
			<xsl:apply-templates select="mdml_protocol"/>
			<xsl:apply-templates select="mdml_appProfile"/>
			<xsl:apply-templates select="mdml_orName"/>
			<xsl:apply-templates select="mdml_orDesc"/>
			<xsl:apply-templates select="mdml_orFunct"/>
		</cntOnLineRes>
	</xsl:template>
	
	<xsl:template match="mdml_linkage">
		<linkage>
			<xsl:value-of select="."/>
		</linkage>
	</xsl:template>
	
	<xsl:template match="mdml_protocol">
		<protocol>
			<xsl:value-of select="."/>
		</protocol>
	</xsl:template>
	
	<xsl:template match="mdml_appProfile">
		<appProfile>
			<xsl:value-of select="."/>
		</appProfile>
	</xsl:template>
	
	<xsl:template match="mdml_orName">
		<orName>
			<xsl:value-of select="."/>
		</orName>
	</xsl:template>
	
	<xsl:template match="mdml_orDesc">
		<orDesc>
			<xsl:value-of select="."/>
		</orDesc>
	</xsl:template>
	
	<xsl:template match="mdml_orFunct">
		<orFunct>
			<xsl:element name="OnFunctCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</orFunct>
	</xsl:template>
	
	<xsl:template match="mdml_cntHours">
		<cntHours>
			<xsl:value-of select="."/>
		</cntHours>
	</xsl:template>
	
	<xsl:template match="mdml_cntInstr">
		<cntInstr>
			<xsl:value-of select="."/>
		</cntInstr>
	</xsl:template>
	
	<xsl:template match="mdml_mdDateSt">
		<mdDateSt>
			<xsl:value-of select="."/>
		</mdDateSt>		
	</xsl:template>
	
	<xsl:template match="mdml_mdStanName">
		<mdStanName>
			<xsl:value-of select="."/>
		</mdStanName>		
	</xsl:template>
	
	<xsl:template match="mdml_mdStanVer">
		<mdStanVer>
			<xsl:value-of select="."/>
		</mdStanVer>		
	</xsl:template>

	<xsl:template match="distTranOps">
		<distTranOps>
			<xsl:apply-templates select="./onLineSrc"/>
		</distTranOps>		
	</xsl:template>

	<xsl:template match="onLineSrc">
		<onLineSrc>
			<xsl:apply-templates select="./mdml_onLineSrc_linkage"/>
			<xsl:apply-templates select="./mdml_onLineSrc_protocol"/>
			<xsl:apply-templates select="./mdml_onLineSrc_appProfile"/>
			<xsl:apply-templates select="./mdml_onLineSrc_orName"/>
			<xsl:apply-templates select="./mdml_onLineSrc_orDesc"/>
			<xsl:apply-templates select="./mdml_onLineSrc_orFunct"/>
		</onLineSrc>		
	</xsl:template>
	
	<xsl:template match="mdml_onLineSrc_linkage">
		<linkage>
			<xsl:value-of select="."/>
		</linkage>
	</xsl:template>
	
	<xsl:template match="mdml_onLineSrc_protocol">
		<protocol>
			<xsl:value-of select="."/>
		</protocol>
	</xsl:template>
	
	<xsl:template match="mdml_onLineSrc_appProfile">
		<appProfile>
			<xsl:value-of select="."/>
		</appProfile>
	</xsl:template>
	
	<xsl:template match="mdml_onLineSrc_orName">
		<orName>
			<xsl:value-of select="."/>
		</orName>
	</xsl:template>
	
	<xsl:template match="mdml_onLineSrc_orDesc">
		<orDesc>
			<xsl:value-of select="."/>
		</orDesc>
	</xsl:template>
	
	<xsl:template match="mdml_onLineSrc_orFunct">
		<orFunct>
			<xsl:element name="OnFunctCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</orFunct>
	</xsl:template>


	<xsl:template match="idCitation">
		<idCitation>
			<xsl:apply-templates select="./mdml_resTitle"/>
			<xsl:apply-templates select="./mdml_resRefDate"/>
		</idCitation>
	</xsl:template>
	
	<xsl:template match="mdml_resTitle">
		<resTitle>
			<xsl:value-of select="."/>
		</resTitle>
	</xsl:template>
	
	<xsl:template match="mdml_resRefDate">
		<resRefDate>
			<xsl:apply-templates select="./mdml_refDate"/>	
			<xsl:apply-templates select="./mdml_refDateType"/>
		</resRefDate>
	</xsl:template>

	<xsl:template match="mdml_refDate">
		<xsl:for-each select=".">
			<refDate>
				<xsl:value-of select="."/>				
			</refDate>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="mdml_refDateType">
		<refDateType>
			<xsl:element name="DateTypCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./mdml_refDateTypeCd/@value"/>
				</xsl:attribute>
			</xsl:element>
		</refDateType>
	</xsl:template>



	<xsl:template match="mdml_idAbs">
		<idAbs>
			<xsl:value-of select="."/>
		</idAbs>
	</xsl:template>
	
	
	
	<xsl:template match="mdml_idPoc">
		<idPoC>
			<xsl:apply-templates select="./mdml_idpoc_rpIndName"/>
			<xsl:apply-templates select="./mdml_idpoc_rpOrgName"/>
			<xsl:apply-templates select="./mdml_idpoc_rpPosName"/>
			<xsl:apply-templates select="./mdml_idpoc_rpCntInfo"/>
			<xsl:apply-templates select="./role"/>
		</idPoC>
	</xsl:template>

	<xsl:template match="mdml_idpoc_rpIndName">
		<rpIndName>
			<xsl:value-of select="."/>
		</rpIndName>
	</xsl:template>	
	
	
	
	
	<xsl:template match="mdml_idpoc_rpOrgName">
		<rpOrgName>
			<xsl:value-of select="."/>
		</rpOrgName>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_rpPosName">
		<rpPosName>
			<xsl:value-of select="."/>
		</rpPosName>
	</xsl:template>
	
	<xsl:template match="role">
		<role>
			<xsl:element name="RoleCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./mdml_idpoc_role/@value"/>
				</xsl:attribute>
			</xsl:element>
		</role>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_rpCntInfo">
		<rpCntInfo>
			<xsl:apply-templates select="mdml_idpoc_cntPhone"/>
			<xsl:apply-templates select="mdml_idpoc_cntAddress"/>
			<xsl:apply-templates select="mdml_idpoc_cntOnlineRes"/>
			<xsl:apply-templates select="mdml_idpoc_cntHours"/>
			<xsl:apply-templates select="mdml_idpoc_cntInstr"/>
		</rpCntInfo>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_cntPhone">
		<cntPhone>
			<xsl:apply-templates select="mdml_idpoc_voiceNum"/>
			<xsl:apply-templates select="mdml_idpoc_faxNum"/>
		</cntPhone>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_voiceNum">
		<voiceNum>
			<xsl:value-of select="."/>
			<xsl:value-of select="./@value"/>
		</voiceNum>
	</xsl:template>
	
	
	<xsl:template match="mdml_idpoc_faxNum">
		<faxNum>
			<xsl:value-of select="."/>
			<xsl:value-of select="./@value"/>
		</faxNum>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_cntAddress">
		<cntAddress>
			<xsl:apply-templates select="mdml_idpoc_delPoint"/>
			<xsl:apply-templates select="mdml_idpoc_city"/>
			<xsl:apply-templates select="mdml_idpoc_adminArea"/>
			<xsl:apply-templates select="mdml_idpoc_postCode"/>
			<xsl:apply-templates select="mdml_idpoc_country"/>
			<xsl:apply-templates select="mdml_idpoc_eMailAdd"/>
		</cntAddress>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_delPoint">
		<delPoint>
			<xsl:value-of select="."/>
			<xsl:value-of select="./@value"/>
		</delPoint>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_city">
		<city>
			<xsl:value-of select="."/>
		</city>
	</xsl:template>
	
	
	<xsl:template match="mdml_idpoc_adminArea">
		<adminArea>
			<xsl:value-of select="."/>
		</adminArea>
	</xsl:template>
	
	
	<xsl:template match="mdml_idpoc_postCode">
		<postCode>
			<xsl:value-of select="."/>
		</postCode>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_country">
		<country>
			<xsl:value-of select="./@value"/>
		</country>
	</xsl:template>
	
	
	<xsl:template match="mdml_idpoc_eMailAdd">
		<eMailAdd>
			<xsl:value-of select="."/>
			<xsl:value-of select="./@value"/>
		</eMailAdd>
	</xsl:template>
	
	
	
	<xsl:template match="mdml_idpoc_cntOnlineRes">
		<cntOnLineRes>
			<xsl:apply-templates select="mdml_idpoc_linkage"/>
			<xsl:apply-templates select="mdml_idpoc_protocol"/>
			<xsl:apply-templates select="mdml_idpoc_appProfile"/>
			<xsl:apply-templates select="mdml_idpoc_orName"/>
			<xsl:apply-templates select="mdml_idpoc_orDesc"/>
			<xsl:apply-templates select="mdml_idpoc_orFunct"/>
		</cntOnLineRes>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_linkage">
		<linkage>
			<xsl:value-of select="."/>
		</linkage>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_protocol">
		<protocol>
			<xsl:value-of select="."/>
		</protocol>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_appProfile">
		<appProfile>
			<xsl:value-of select="."/>
		</appProfile>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_orName">
		<orName>
			<xsl:value-of select="."/>
		</orName>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_orDesc">
		<orDesc>
			<xsl:value-of select="."/>
		</orDesc>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_orFunct">
		<orFunct>
			<xsl:element name="OnFunctCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</orFunct>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_cntHours">
		<cntHours>
			<xsl:value-of select="."/>
		</cntHours>
	</xsl:template>
	
	<xsl:template match="mdml_idpoc_cntInstr">
		<cntInstr>
			<xsl:value-of select="."/>
		</cntInstr>
	</xsl:template>


		
	<xsl:template match="spatRpType">
			<spatRpType>
				<xsl:element name="SpatRepTypCd">
				 	<xsl:attribute name="value">
				 		<xsl:value-of select="./mdml_spatRpType"/>
				 	</xsl:attribute>
				</xsl:element>
			</spatRpType>
	</xsl:template>
	
	
	<xsl:template match="mdml_dataScale">
		<dataScale>
			<xsl:apply-templates select="./mdml_equScale"/>
			<xsl:apply-templates select="./mdml_scaleDist"/>
		</dataScale>
	</xsl:template>
	
	
	<xsl:template match="mdml_equScale">
		<equScale>
			<xsl:apply-templates select="./mdml_rfDenom"/>
		</equScale>
	</xsl:template>
	
	
	<xsl:template match="mdml_rfDenom">
		<rfDenom>
			<xsl:value-of select="."/>
		</rfDenom>
	</xsl:template>
	
	
	<xsl:template match="mdml_scaleDist">
		<scaleDist>
			<xsl:apply-templates select="./mdml_value"/>
			<xsl:apply-templates select="./mdml_uom"/>
		</scaleDist>
	</xsl:template>
	
	<xsl:template match="mdml_value">
		<value>
			<xsl:value-of select="."/>
		</value>
	</xsl:template>
	
	<xsl:template match="mdml_uom">
		<uom>
			<uomScale>
				<uomName>
					<xsl:value-of select="./mdml_uomScale/mdml_uomName"/>
				</uomName>
				<conversionToISOstandardUnit>
					<xsl:value-of select="./mdml_uomScale/mdml_conversionToISOstandardUnit"/>
				</conversionToISOstandardUnit>
			</uomScale>
		</uom>
	</xsl:template>
	
	
	
	<xsl:template match="dataLang">
		<xsl:for-each select="./mdml_dataLang">
			<dataLang>
				<xsl:element name="languageCode">
					<xsl:attribute name="value">
						<xsl:value-of select="./@value"/>
					</xsl:attribute>
				</xsl:element>
			</dataLang>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="dataChar">
		<xsl:for-each select="./mdml_dataChar">
			<dataChar>
				<xsl:element name="CharSetCd">
					<xsl:attribute name="value">
						<xsl:value-of select="./@value"/>
					</xsl:attribute>
				</xsl:element>
			</dataChar>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="tpCat">
		<tpCat>
			<xsl:element name="TopicCatCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./mdml_tpCat/@value"/>
				</xsl:attribute>
			</xsl:element>
		</tpCat>
	</xsl:template>
	
	<xsl:template match="geoBox">
		<geoBox>
			<westBL>
				<xsl:value-of select="./mdml_westBL"/>
			</westBL>
			<eastBL>
				<xsl:value-of select="./mdml_eastBL"/>
			</eastBL>
			<southBL>
				<xsl:value-of select="./mdml_southBL"/>
			</southBL>
			<northBL>
				<xsl:value-of select="./mdml_northBL"/>
			</northBL>
		</geoBox>
	</xsl:template>
	
	<xsl:template match="mdml_geoId">
		<geoDesc>
			<geoId>
				<xsl:apply-templates select="./mdml_identAuth"/>
				<xsl:apply-templates select="./mdml_identCode"/>
			</geoId>

		</geoDesc>
		
	</xsl:template>
	
	<xsl:template match="mdml_identAuth">
		<identAuth>
			<xsl:apply-templates select="mdml_resTitle"/>
			<xsl:apply-templates select="mdml_resRefDate"/>
		</identAuth>
	</xsl:template>
	

	<xsl:template match="mdml_version">
		<identVrsn>
			<xsl:value-of select="."/>
		</identVrsn>
	</xsl:template>

	
	<xsl:template match="mdml_dsFormat">
		<dsFormat>
			<xsl:apply-templates select="mdml_formatName"/>
			<xsl:apply-templates select="mdml_formatVer"/>
		</dsFormat>
	</xsl:template>
	
	<xsl:template match="mdml_formatName">
		<formatName>
			<xsl:value-of select="."/>
		</formatName>
	</xsl:template>
	
	<xsl:template match="mdml_formatVer">
		<formatVer>
			<xsl:value-of select="."/>
		</formatVer>
	</xsl:template>
	
	<xsl:template match="mdml_TM_Period">
		<dataExt>
			<tempEle>
				<TempExtent>
					<exTemp>
						<TM_GeometricPrimitive>
							<TM_Period>
								<begin>
									<xsl:value-of select="./mdml_begin"/>
								</begin>
								<end>
									<xsl:value-of select="./mdml_end"/>	
								</end>
							</TM_Period>
						</TM_GeometricPrimitive>
					</exTemp>
				</TempExtent>
			</tempEle>
		</dataExt>
	</xsl:template>
	
	
	<xsl:template match="dataLineage">
		<dataLineage>
			<xsl:apply-templates select="./mdml_statement"/>
			<!--
			<xsl:apply-templates select="./dataSource"/>
			<xsl:apply-templates select="./prcStep"/>
			-->
		</dataLineage>
	</xsl:template>
	
	<xsl:template match="mdml_statement">
		<statement>
			<xsl:value-of select="."/>
		</statement>
	</xsl:template>
	
	<!--
	<xsl:template match="dataSource">
		<dataSource>
			<xsl:apply-templates select="./mdml_dataSource_srcDesc"/>
			<xsl:apply-templates select="./mdml_dataSource_srcScale"/>
			<xsl:apply-templates select="./mdml_dataSource_srcRefSys"/>
			<xsl:apply-templates select="./mdml_dataSource_srcCitatn"/>
			<xsl:apply-templates select="./mdml_dataSource_srcExt"/>
		</dataSource>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_srcDesc">
		<srcDesc>
			<xsl:value-of select="."/>
		</srcDesc>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_srcScale">
		<srcScale>
			<rfDenom>
				<xsl:value-of select="./mdml_dataSource_rfDenom"/>
			</rfDenom>
		</srcScale>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_srcRefSys">
		<srcRefSys>
			<RefSystem>
				<refSysID>
					<xsl:apply-templates select="./mdml_dataSource_RefSystem/mdml_dataSource_refSysID/mdml_dataSource_identAuth"/>
					<xsl:apply-templates select="./mdml_dataSource_RefSystem/mdml_dataSource_refSysID/mdml_dataSource_identCode"/>
				</refSysID>
			</RefSystem>
		</srcRefSys>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_identAuth">
		<identAuth>
			<xsl:apply-templates select="./mdml_dataSource_resTitle"/>
			<xsl:apply-templates select="./mdml_dataSource_resRefDate"/>
		</identAuth>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_resTitle">
		<resTitle>
			<xsl:value-of select="."/>
		</resTitle>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_resRefDate">
		<resRefDate>
			<xsl:apply-templates select="./mdml_dataSource_refDate"/>	
			<xsl:apply-templates select="./mdml_dataSource_refDateType/mdml_dataSource_refDateTypeCd"/>
		</resRefDate>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_refDate">
		<xsl:for-each select=".">
			<refDate>
				<xsl:value-of select="./@value"/>
				<xsl:value-of select="."/>				
			</refDate>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_refDateTypeCd">
		<refDateType>
			<xsl:element name="DateTypCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</refDateType>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_identCode">
		<identCode>
			<xsl:value-of select="."/>
		</identCode>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_srcCitatn">
		<srcCitatn>
			<xsl:apply-templates select="./mdml_ds_resTitle"/>
			<xsl:apply-templates select="./mdml_ds_resRefDate"/>
		</srcCitatn>
	</xsl:template>
	
	
	
	<xsl:template match="mdml_ds_resTitle">
		<resTitle>
			<xsl:value-of select="."/>
		</resTitle>
	</xsl:template>
	
	<xsl:template match="mdml_ds_resRefDate">
		<resRefDate>
			<xsl:apply-templates select="./mdml_ds_refDate"/>	
			<xsl:apply-templates select="./mdml_ds_refDateType/mdml_ds_refDateTypeCd"/>
		</resRefDate>
	</xsl:template>
	
	<xsl:template match="mdml_ds_refDate">
		<xsl:for-each select=".">
			<refDate>
				<xsl:value-of select="."/>				
			</refDate>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="mdml_ds_refDateTypeCd">
		<refDateType>
			<xsl:element name="DateTypCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</refDateType>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_srcExt">
		<srcExt>
			<xsl:apply-templates select="./mdml_dataSource_exDesc"/>	
			<xsl:apply-templates select="./mdml_dataSource_vertEle"/>
			<xsl:apply-templates select="./mdml_dataSource_tempEle"/>	
			<xsl:apply-templates select="./mdml_dataSource_geoEle"/>
		</srcExt>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_exDesc">
		<exDesc>
			<xsl:value-of select="."/>
		</exDesc>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_vertEle">
		<vertEle>
			<vertMinVal>
				<xsl:value-of select="./mdml_dataSource_vertMinVal"/>	
			</vertMinVal>
			<vertMaxVal>
				<xsl:value-of select="./mdml_dataSource_vertMaxVal"/>	
			</vertMaxVal>
			<vertUoM>
				<uomName>
					<xsl:value-of select="./mdml_dataSource_vertUoM/mdml_dataSource_uomName"/>
				</uomName>
				<conversionToISOstandardUnit>
					<xsl:value-of select="./mdml_dataSource_vertUoM/mdml_dataSource_conversionToISOstandardUnit"/>
				</conversionToISOstandardUnit>				
			</vertUoM>
			<vertDatum>
				<datumID>
					<identCode>
						<xsl:value-of select="./mdml_dataSource_vertDatum/mdml_dataSource_datumID/mdml_vd_identCode"/>
					</identCode>
				</datumID>
			</vertDatum>
		</vertEle>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_tempEle">
		<tempEle>
			<TempExtent>	
				<exTemp>
					<TM_GeometricPrimitive>
						<TM_Period>
							<begin>
								<xsl:value-of select="./mdml_dataSource_TempExtent/mdml_dataSource_exTemp/mdml_dataSource_TM_GeometricPrimitive/mdml_dataSource_TM_Period/mdml_dataSource_begin"/>
							</begin>
							<end>
								<xsl:value-of select="./mdml_dataSource_TempExtent/mdml_dataSource_exTemp/mdml_dataSource_TM_GeometricPrimitive/mdml_dataSource_TM_Period/mdml_dataSource_begin"/>	
							</end>
						</TM_Period>
					</TM_GeometricPrimitive>
				</exTemp>
			</TempExtent>
		</tempEle>
	</xsl:template>
	
	<xsl:template match="mdml_dataSource_geoEle">
		<GeoDesc>
			<geoId>
				<identCode>
					<xsl:value-of select="./mdml_dataSource_GeoDesc/mdml_dataSource_geoId/mdml_ge_identCode"/>
				</identCode>
			</geoId>
		</GeoDesc>
	</xsl:template>
	
	<xsl:template match="prcStep">
		<stepDesc>
			<xsl:value-of select="./mdml_stepDesc"/>
		</stepDesc>
		<stepRat>
			<xsl:value-of select="./mdml_stepRat"/>
		</stepRat>
		<stepDateTm>
			<xsl:value-of select="./mdml_stepDateTm"/>
		</stepDateTm>
		<stepProc>
			<xsl:apply-templates select="./mdml_stepProc"/>
		</stepProc>
		<stepSrc>
			<xsl:apply-templates select="mdml_stepSrc"/>
		</stepSrc>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc">
		<stepProc>
			<rpIndName><xsl:value-of select="./mdml_stepProc_rpIndName"/></rpIndName>
			<rpOrgName><xsl:value-of select="./mdml_stepProc_rpOrgName"/></rpOrgName>
			<rpPosName><xsl:value-of select="./mdml_stepProc_rpPosName"/></rpPosName>
			<rpCntInfo><xsl:apply-templates select="./mdml_stepProc_rpCntInfo"/></rpCntInfo>
			<role>
				<xsl:element name="RoleCd">
					<xsl:attribute name="value">
						<xsl:value-of select="./role/mdml_stepProc_role/@value"/>
					</xsl:attribute>
				</xsl:element>
			</role>
		</stepProc>
	</xsl:template>
	
	
	<xsl:template match="mdml_stepProc_rpIndName">
		<rpIndName>
			<xsl:value-of select="."/>
		</rpIndName>
	</xsl:template>	
	
	
	
	
	<xsl:template match="mdml_stepProc_rpOrgName">
		<rpOrgName>
			<xsl:value-of select="."/>
		</rpOrgName>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_rpPosName">
		<rpPosName>
			<xsl:value-of select="."/>
		</rpPosName>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_role">
		<role>
			<xsl:element name="RoleCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</role>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_rpCntInfo">
		<rpCntInfo>
			<xsl:apply-templates select="mdml_stepProc_cntPhone"/>
			<xsl:apply-templates select="mdml_stepProc_cntAddress"/>
			<xsl:apply-templates select="mdml_stepProc_cntOnlineRes"/>
			<xsl:apply-templates select="mdml_stepProc_cntHours"/>
			<xsl:apply-templates select="mdml_stepProc_cntInstr"/>
		</rpCntInfo>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_cntPhone">
		<cntPhone>
			<xsl:apply-templates select="mdml_stepProc_voiceNum"/>
			<xsl:apply-templates select="mdml_stepProc_faxNum"/>
		</cntPhone>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_voiceNum">
		<voiceNum>
			<xsl:value-of select="./@value"/>
			<xsl:value-of select="."/>
		</voiceNum>
	</xsl:template>
	
	
	<xsl:template match="mdml_stepProc_faxNum">
		<faxNum>
			<xsl:value-of select="./@value"/>
			<xsl:value-of select="."/>
		</faxNum>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_cntAddress">
		<cntAddress>
			<xsl:apply-templates select="mdml_stepProc_delPoint"/>
			<xsl:apply-templates select="mdml_stepProc_city"/>
			<xsl:apply-templates select="mdml_stepProc_adminArea"/>
			<xsl:apply-templates select="mdml_stepProc_postCode"/>
			<xsl:apply-templates select="mdml_stepProc_country"/>
			<xsl:apply-templates select="mdml_stepProc_eMailAdd"/>
		</cntAddress>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_delPoint">
		<delPoint>
			<xsl:value-of select="./@value"/>
			<xsl:value-of select="."/>
		</delPoint>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_city">
		<city>
			<xsl:value-of select="."/>
		</city>
	</xsl:template>
	
	
	<xsl:template match="mdml_stepProc_adminArea">
		<adminArea>
			<xsl:value-of select="."/>
		</adminArea>
	</xsl:template>
	
	
	<xsl:template match="mdml_stepProc_postCode">
		<postCode>
			<xsl:value-of select="."/>
		</postCode>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_country">
		<country>
			<xsl:value-of select="./@value"/>
		</country>
	</xsl:template>
	
	
	<xsl:template match="mdml_stepProc_eMailAdd">
		<eMailAdd>
			<xsl:value-of select="./@value"/>
			<xsl:value-of select="."/>
		</eMailAdd>
	</xsl:template>
	
	
	
	<xsl:template match="mdml_stepProc_cntOnlineRes">
		<cntOnlineRes>
			<xsl:apply-templates select="mdml_stepProc_linkage"/>
			<xsl:apply-templates select="mdml_stepProc_protocol"/>
			<xsl:apply-templates select="mdml_stepProc_appProfile"/>
			<xsl:apply-templates select="mdml_stepProc_orName"/>
			<xsl:apply-templates select="mdml_stepProc_orDesc"/>
			<xsl:apply-templates select="mdml_stepProc_orFunct"/>
		</cntOnlineRes>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_linkage">
		<linkage>
			<xsl:value-of select="."/>
		</linkage>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_protocol">
		<protocol>
			<xsl:value-of select="."/>
		</protocol>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_appProfile">
		<appProfile>
			<xsl:value-of select="."/>
		</appProfile>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_orName">
		<orName>
			<xsl:value-of select="."/>
		</orName>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_orDesc">
		<orDesc>
			<xsl:value-of select="."/>
		</orDesc>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_orFunct">
		<orFunct>
			<xsl:value-of select="./@value"/>
		</orFunct>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_cntHours">
		<cntHours>
			<xsl:value-of select="."/>
		</cntHours>
	</xsl:template>
	
	<xsl:template match="mdml_stepProc_cntInstr">
		<cntInstr>
			<xsl:value-of select="."/>
		</cntInstr>
	</xsl:template>
	
	<xsl:template match="mdml_stepSrc">
		<stepSrc>
			<xsl:apply-templates select="./mdml_srcDesc"/>
			<xsl:apply-templates select="./mdml_srcScale"/>
			<xsl:apply-templates select="./mdml_srcRefSys"/>
			<xsl:apply-templates select="./mdml_srcCitatn"/>
			<xsl:apply-templates select="./mdml_stepSrc_srcExt"/>
		</stepSrc>
	</xsl:template>
	
	<xsl:template match="mdml_srcDesc">
		<srcDesc>
			<xsl:value-of select="."/>
		</srcDesc>
	</xsl:template>
	
	<xsl:template match="mdml_srcScale">
		<srcScale>
			<rfDenom>
				<xsl:value-of select="./mdml_srcScale_rfDenom"/>
			</rfDenom>
		</srcScale>
	</xsl:template>
	
	<xsl:template match="mdml_srcRefSys">
		<srcRefSys>
			<RefSystem>
				<refSysID>
					<xsl:apply-templates select="./mdml_srcRefSys_RefSystem/mdml_srcRefSys_refSysID/mdml_srcRefSys_identAuth"/>
					<xsl:apply-templates select="./mdml_srcRefSys_RefSystem/mdml_srcRefSys_refSysID/mdml_refSys_identCode"/>
				</refSysID>
			</RefSystem>
		</srcRefSys>
	</xsl:template>
	
	<xsl:template match="mdml_srcRefSys_identAuth">
		<identAuth>
			<xsl:apply-templates select="./mdml_srcRefSys_resTitle"/>
			<xsl:apply-templates select="./mdml_srcRefSys_resRefDate"/>
		</identAuth>
	</xsl:template>
	
	<xsl:template match="mdml_srcRefSys_resTitle">
		<resTitle>
			<xsl:value-of select="."/>
		</resTitle>
	</xsl:template>
	
	<xsl:template match="mdml_srcRefSys_resRefDate">
		<resRefDate>
			<xsl:apply-templates select="./mdml_srcRefSys_refDate"/>	
			<xsl:apply-templates select="./mdml_srcRefSys_refDateType/mdml_srcRefSys_refDateTypeCd"/>
		</resRefDate>
	</xsl:template>
	
	<xsl:template match="mdml_srcRefSys_refDate">
		<xsl:for-each select=".">
			<refDate>
				<xsl:value-of select="./@value"/>
				<xsl:value-of select="."/>				
			</refDate>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="mdml_srcRefSys_refDateTypeCd">
		<refDateType>
			<xsl:element name="DateTypCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</refDateType>
	</xsl:template>
	
	<xsl:template match="mdml_refSys_identCode">
		<identCode>
			<xsl:value-of select="."/>
		</identCode>
	</xsl:template>
	
	<xsl:template match="mdml_srcCitatn">
		<srcCitatn>
			<xsl:apply-templates select="./mdml_srcCitatn_resTitle"/>
			<xsl:apply-templates select="./mdml_srcCitatn_resRefDate"/>
		</srcCitatn>
	</xsl:template>
	
	
	
	<xsl:template match="mdml_srcCitatn_resTitle">
		<resTitle>
			<xsl:value-of select="."/>
		</resTitle>
	</xsl:template>
	
	<xsl:template match="mdml_srcCitatn_resRefDate">
		<resRefDate>
			<xsl:apply-templates select="./mdml_srcCitatn_refDate"/>	
			<xsl:apply-templates select="./mdml_srcCitatn_refDateType/mdml_srcCitatn_refDateTypeCd"/>
		</resRefDate>
	</xsl:template>
	
	<xsl:template match="mdml_srcCitatn_refDate">
		<xsl:for-each select=".">
			<refDate>
				<xsl:value-of select="."/>				
			</refDate>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template match="mdml_srcCitatn_refDateTypeCd">
		<refDateType>
			<xsl:element name="DateTypCd">
				<xsl:attribute name="value">
					<xsl:value-of select="./@value"/>
				</xsl:attribute>
			</xsl:element>
		</refDateType>
	</xsl:template>
	
	<xsl:template match="mdml_stepSrc_srcExt">
		<srcExt>
			<xsl:apply-templates select="./mdml_stepSrc_exDesc"/>	
			<xsl:apply-templates select="./mdml_stepSrc_vertEle"/>
			<xsl:apply-templates select="./mdml_stepSrc_tempEle"/>	
			<xsl:apply-templates select="./mdml_stepSrc_geoEle"/>
		</srcExt>
	</xsl:template>
	
	<xsl:template match="mdml_stepSrc_exDesc">
		<exDesc>
			<xsl:value-of select="."/>
		</exDesc>
	</xsl:template>
	
	<xsl:template match="mdml_stepSrc_vertEle">
		<vertEle>
			<vertMinVal>
				<xsl:value-of select="./mdml_stepSrc_vertMinVal"/>	
			</vertMinVal>
			<vertMaxVal>
				<xsl:value-of select="./mdml_stepSrc_vertMaxVal"/>	
			</vertMaxVal>
			<vertUoM>
				<uomName>
					<xsl:value-of select="./mdml_stepSrc_vertUoM/mdml_stepSrc_uomName"/>
				</uomName>
				<conversionToISOstandardUnit>
					<xsl:value-of select="./mdml_stepSrc_vertUoM/mdml_stepSrc_conversionToISOstandardUnit"/>
				</conversionToISOstandardUnit>				
			</vertUoM>
			<vertDatum>
				<datumID>
					<identCode>
						<xsl:value-of select="./mdml_stepSrc_vertDatum/mdml_stepSrc_datumID/mdml_stepSrc_identCode"/>
					</identCode>
				</datumID>
			</vertDatum>
		</vertEle>
	</xsl:template>
	
	<xsl:template match="mdml_stepSrc_tempEle">
		<tempEle>
			<TempExtent>	
				<exTemp>
					<TM_GeometricPrimitive>
						<TM_Period>
							<begin>
								<xsl:value-of select="./mdml_stepSrc_TempExtent/mdml_stepSrc_exTemp/stepSrc_TM_GeometricPrimitive/stepSrc_TM_Period/mdml_stepSrc_begin"/>
							</begin>
							<end>
								<xsl:value-of select="./mdml_stepSrc_TempExtent/mdml_stepSrc_exTemp/stepSrc_TM_GeometricPrimitive/stepSrc_TM_Period/mdml_stepSrc_end"/>	
							</end>
						</TM_Period>
					</TM_GeometricPrimitive>
				</exTemp>
			</TempExtent>
		</tempEle>
	</xsl:template>
	
	<xsl:template match="mdml_stepSrc_geoEle">
		<GeoDesc>
			<geoId>
				<identCode>
					<xsl:value-of select="./mdml_stepSrc_GeoDesc/mdml_stepSrc_geoId/mdml_ss_identCode"/>
				</identCode>
			</geoId>
		</GeoDesc>
	</xsl:template>		
	-->
	
	
	<xsl:template match="mdml_refSysInfo">
			<RefSystem>
				<refSysID>
					<identCode>
						<xsl:value-of select="./mdml_RefSystem/mdml_refSysID/mdml_refSystem_identCode"/>
					</identCode>
				</refSysID>
			</RefSystem>
	</xsl:template>
			
</xsl:stylesheet>